<?php

namespace Piwik\Plugins\IP2Location\LocationProvider;

use Piwik\Http;
use Piwik\Option;
use Piwik\Piwik;
use Piwik\Plugins\UserCountry\LocationProvider;

class IP2Location extends LocationProvider
{
	const ID = 'ip2location';
	const TITLE = 'IP2Location';

	public function __construct()
	{
	}

	/**
	 * Returns information about this location provider.
	 *
	 * @return array
	 */
	public function getInfo()
	{
		$extraMessage = '';

		if (Option::get('IP2Location.LookupMode') == 'WS') {
			$extraMessage = '
				<strong>Lookup Mode: </strong>IP2Location Web Service<br/>
				<strong>API Key: </strong>' . Option::get('IP2Location.APIKey');
		} else {
			if ($this->getDatabasePath()) {
				$extraMessage = '
				<strong>Lookup Mode: </strong>IP2Location BIN Database<br/>
				<strong>Database File: </strong>' . basename($this->getDatabasePath());
			}
		}

		return [
			'id'          => self::ID,
			'title'       => self::TITLE,
			'order'       => 5,
			'description' => implode("\n", [
				'<p>',
				'This location provider uses <strong>IP2Location database</strong> to accurately detect the location of your visitors.',
				'It support both IPv4 and IPv6 address detection. In addition, you can choose to use either BIN database or web service for the geolocation lookup.',
				'</p>',
				'<p><ul>',
				'<li><a href="https://lite.ip2location.com/?r=piwik" rel="noreferrer"  target="_blank">Download free IP2Location LITE BIN database &raquo;</a></li>',
				'<li><a href="https://www.ip2location.com/?r=piwik" rel="noreferrer"  target="_blank">Download free IP2Location Commercial BIN database &raquo;</a></li>',
				'<li><a href="https://www.ip2location.com/web-service/ip2location/?r=piwik" rel="noreferrer"  target="_blank">Sign up for web service &raquo;</a></li>',
				'</ul></p>',
			]),
			'install_docs'  => 'For BIN database option, please upload IP2Location BIN database file into <strong>Piwik/misc</strong> folder.',
			'extra_message' => $extraMessage,
		];
	}

	/**
	 * Get a visitor's location based on their IP address.
	 *
	 * @param array $info must have an 'ip' field
	 *
	 * @return array
	 */
	public function getLocation($info)
	{
		$ip = $this->getIpFromInfo($info);

		$result = [];

		if (Option::get('IP2Location.LookupMode') == 'WS' && Option::get('IP2Location.APIKey')) {
			$response = Http::sendHttpRequest('https://api.ip2location.com/v2/?key=' . Option::get('IP2Location.APIKey') . '&ip=' . $ip . '&format=json&package=WS6', 30);

			if (($json = json_decode($response)) !== null) {
				if (!isset($json->response)) {
					$result[self::COUNTRY_CODE_KEY] = $json->country_code;
					$result[self::COUNTRY_NAME_KEY] = $json->country_name;
					$result[self::REGION_CODE_KEY] = $this->getRegionCode($json->country_code, $json->region_name);
					$result[self::REGION_NAME_KEY] = $json->region_name;
					$result[self::CITY_NAME_KEY] = $json->city_name;
					$result[self::LATITUDE_KEY] = $json->latitude;
					$result[self::LONGITUDE_KEY] = $json->longitude;
					$result[self::ISP_KEY] = $json->isp;
				}
			}
		} else {
			require_once PIWIK_INCLUDE_PATH . '/plugins/IP2Location/lib/IP2Location.php';

			$db = new \IP2Location\Database(self::getDatabasePath(), \IP2Location\Database::FILE_IO);
			$response = $db->lookup($ip, \IP2Location\Database::ALL);

			$result[self::COUNTRY_CODE_KEY] = $response['countryCode'];
			$result[self::COUNTRY_NAME_KEY] = $response['countryName'];

			if (strpos($response['regionName'], 'unavailable') === false) {
				$result[self::REGION_CODE_KEY] = $this->getRegionCode($response['countryCode'], $response['regionName']);
				$result[self::REGION_NAME_KEY] = $response['regionName'];
			}

			if (strpos($response['cityName'], 'unavailable') === false) {
				$result[self::CITY_NAME_KEY] = $response['cityName'];
			}

			if (strpos($response['latitude'], 'unavailable') === false) {
				$result[self::LATITUDE_KEY] = $response['latitude'];
				$result[self::LONGITUDE_KEY] = $response['longitude'];
			}

			if (strpos($response['isp'], 'unavailable') === false) {
				$result[self::ISP_KEY] = $response['isp'];
			}
		}

		$this->completeLocationResult($result);

		return $result;
	}

	/**
	 * Returns an array describing the types of location information this provider will
	 * return.
	 *
	 * @return array
	 */
	public function getSupportedLocationInfo()
	{
		$result = [];

		// Country & continent information always available
		$result[self::COUNTRY_CODE_KEY] = true;
		$result[self::COUNTRY_NAME_KEY] = true;
		$result[self::CONTINENT_CODE_KEY] = true;
		$result[self::CONTINENT_NAME_KEY] = true;

		require_once PIWIK_INCLUDE_PATH . '/plugins/IP2Location/lib/IP2Location.php';

		$db = new \IP2Location\Database(self::getDatabasePath(), \IP2Location\Database::FILE_IO);
		$response = $db->lookup('8.8.8.8', \IP2Location\Database::ALL);

		if (strpos($response['regionName'], 'unavailable') === false) {
			$result[self::REGION_CODE_KEY] = true;
			$result[self::REGION_NAME_KEY] = true;
		}

		if (strpos($response['cityName'], 'unavailable') === false) {
			$result[self::CITY_NAME_KEY] = true;
		}

		if (strpos($response['latitude'], 'unavailable') === false) {
			$result[self::LATITUDE_KEY] = true;
			$result[self::LONGITUDE_KEY] = true;
		}

		if (strpos($response['isp'], 'unavailable') === false) {
			$result[self::ISP_KEY] = true;
		}

		return $result;
	}

	/**
	 * Returns true if this location provider is available.
	 *
	 * @return bool
	 */
	public function isAvailable()
	{
		if (Option::get('IP2Location.APIKey') || self::getDatabasePath() !== false) {
			return true;
		}

		return false;
	}

	/**
	 * Returns true if this provider has been setup correctly, the error message if
	 * otherwise.
	 *
	 * @return bool|string
	 */
	public function isWorking()
	{
		if (!empty(Option::get('IP2Location.APIKey'))) {
			return true;
		}

		require_once PIWIK_INCLUDE_PATH . '/plugins/IP2Location/lib/IP2Location.php';

		if (!file_exists(self::getDatabasePath())) {
			return 'The IP2Location BIN database file is not found.';
		}

		$db = new \IP2Location\Database(self::getDatabasePath(), \IP2Location\Database::FILE_IO);
		$response = $db->lookup('8.8.8.8', \IP2Location\Database::ALL);

		if (!isset($response['countryCode'])) {
			return 'The IP2Location database file is corrupted.';
		}

		if (strpos($response['countryCode'], 'Invalid') !== false) {
			return 'The IP2Location database file is corrupted.';
		}

		return true;
	}

	/**
	 * Returns full path for a IP2Location database file.
	 *
	 * @return string
	 */
	public static function getDatabasePath()
	{
		// Scan misc directory for any file with .BIN extension
		$files = scandir(PIWIK_INCLUDE_PATH . '/misc');

		if (empty($files)) {
			return false;
		}

		foreach ($files as $file) {
			if (strtoupper(substr($file, -4)) == '.BIN') {
				return PIWIK_INCLUDE_PATH . '/misc/' . $file;
			}
		}

		return false;
	}

	/**
	 * Get region code by country code and region name.
	 *
	 * @param $countryCode
	 * @param $regionName
	 *
	 * @return false|string
	 */
	private function getRegionCode($countryCode, $regionName)
	{
		$regions = ['AD' => ['02' => 'Canillo', '03' => 'Encamp', '04' => 'La Massana', '05' => 'Ordino', '06' => 'Sant Julia de Loria', '07' => 'Andorra la Vella', '08' => 'Escaldes-Engordany'], 'AE' => ['01' => 'Abu Zaby', '02' => '\'Ajman', '03' => 'Dubayy', '04' => 'Al Fujayrah', '05' => 'Ra\'s al Khaymah', '06' => 'Ash Shariqah', '07' => 'Umm al Qaywayn'], 'AF' => ['01' => 'Badakhshan', '02' => 'Badghis', '03' => 'Baghlan', '05' => 'Bamyan', '06' => 'Farah', '07' => 'Faryab', '08' => 'Ghazni', '09' => 'Ghor', '10' => 'Helmand', '11' => 'Herat', '13' => 'Kabul', '14' => 'Kapisa', '17' => 'Logar', '18' => 'Nangarhar', '19' => 'Nimroz', '23' => 'Kandahar', '24' => 'Kunduz', '26' => 'Takhar', '27' => 'Wardak', '28' => 'Zabul', '29' => 'Paktika', '30' => 'Balkh', '31' => 'Jowzjan', '32' => 'Samangan', '33' => 'Sar-e Pul', '34' => 'Kunar', '35' => 'Laghman', '36' => 'Paktiya', '37' => 'Khost', '38' => 'Nuristan', '39' => 'Uruzgan', '40' => 'Parwan', '41' => 'Daykundi', '42' => 'Panjshayr'], 'AG' => ['01' => 'Barbuda', '03' => 'Saint George', '04' => 'Saint John', '05' => 'Saint Mary', '06' => 'Saint Paul', '07' => 'Saint Peter', '08' => 'Saint Philip', '09' => 'Redonda'], 'AL' => ['40' => 'Berat', '41' => 'Diber', '42' => 'Durres', '43' => 'Elbasan', '44' => 'Fier', '45' => 'Gjirokaster', '46' => 'Korce', '47' => 'Kukes', '48' => 'Lezhe', '49' => 'Shkoder', '50' => 'Tirane', '51' => 'Vlore'], 'AM' => ['01' => 'Aragacotn', '02' => 'Ararat', '03' => 'Armavir', '04' => 'Gegark\'unik\'', '05' => 'Kotayk\'', '06' => 'Lori', '07' => 'Sirak', '08' => 'Syunik\'', '09' => 'Tavus', '10' => 'Vayoc Jor', '11' => 'Erevan'], 'AO' => ['01' => 'Benguela', '02' => 'Bie', '03' => 'Cabinda', '04' => 'Kuando Kubango', '05' => 'Kwanza Norte', '06' => 'Kwanza Sul', '07' => 'Cunene', '08' => 'Huambo', '09' => 'Huila', '12' => 'Malange', '13' => 'Namibe', '14' => 'Moxico', '15' => 'Uige', '16' => 'Zaire', '17' => 'Lunda Norte', '18' => 'Lunda Sul', '19' => 'Bengo', '20' => 'Luanda'], 'AR' => ['01' => 'Buenos Aires', '02' => 'Catamarca', '03' => 'Chaco', '04' => 'Chubut', '05' => 'Cordoba', '06' => 'Corrientes', '07' => 'Ciudad Autonoma de Buenos Aires', '08' => 'Entre Rios', '09' => 'Formosa', '10' => 'Jujuy', '11' => 'La Pampa', '12' => 'La Rioja', '13' => 'Mendoza', '14' => 'Misiones', '15' => 'Neuquen', '16' => 'Rio Negro', '17' => 'Salta', '18' => 'San Juan', '19' => 'San Luis', '20' => 'Santa Cruz', '21' => 'Santa Fe', '22' => 'Santiago del Estero', '23' => 'Tierra del Fuego', '24' => 'Tucuman'], 'AT' => ['01' => 'Burgenland', '02' => 'Karnten', '03' => 'Niederosterreich', '04' => 'Oberosterreich', '05' => 'Salzburg', '06' => 'Steiermark', '07' => 'Tirol', '08' => 'Vorarlberg', '09' => 'Wien'], 'AU' => ['01' => 'Australian Capital Territory', '02' => 'New South Wales', '03' => 'Northern Territory', '04' => 'Queensland', '05' => 'South Australia', '06' => 'Tasmania', '07' => 'Victoria', '08' => 'Western Australia'], 'AZ' => ['01' => 'Abseron', '02' => 'Agcabadi', '03' => 'Agdam', '04' => 'Agdas', '05' => 'Agstafa', '06' => 'Agsu', '07' => 'Sirvan', '08' => 'Astara', '09' => 'Baki', '10' => 'Balakan', '11' => 'Barda', '12' => 'Beylaqan', '13' => 'Bilasuvar', '14' => 'Cabrayil', '15' => 'Calilabad', '16' => 'Daskasan', '18' => 'Fuzuli', '19' => 'Gadabay', '20' => 'Ganca', '21' => 'Goranboy', '22' => 'Goycay', '23' => 'Haciqabul', '24' => 'Imisli', '25' => 'Ismayilli', '26' => 'Kalbacar', '27' => 'Kurdamir', '28' => 'Lacin', '29' => 'Lankaran', '30' => 'Lankaran', '31' => 'Lerik', '32' => 'Masalli', '33' => 'Mingacevir', '34' => 'Naftalan', '35' => 'Naxcivan', '36' => 'Neftcala', '37' => 'Oguz', '38' => 'Qabala', '39' => 'Qax', '40' => 'Qazax', '41' => 'Qobustan', '42' => 'Quba', '43' => 'Qubadli', '44' => 'Qusar', '45' => 'Saatli', '46' => 'Sabirabad', '47' => 'Saki', '48' => 'Saki', '49' => 'Salyan', '50' => 'Samaxi', '51' => 'Samkir', '52' => 'Samux', '53' => 'Siyazan', '54' => 'Sumqayit', '55' => 'Susa', '56' => 'Susa', '57' => 'Tartar', '58' => 'Tovuz', '59' => 'Ucar', '60' => 'Xacmaz', '61' => 'Xankandi', '62' => 'Goygol', '63' => 'Xizi', '64' => 'Xocali', '65' => 'Xocavand', '66' => 'Yardimli', '67' => 'Yevlax', '68' => 'Yevlax', '69' => 'Zangilan', '70' => 'Zaqatala', '71' => 'Zardab'], 'BA' => ['01' => 'Federacija Bosne i Hercegovine', '02' => 'Republika Srpska'], 'BB' => ['01' => 'Christ Church', '02' => 'Saint Andrew', '03' => 'Saint George', '04' => 'Saint James', '05' => 'Saint John', '06' => 'Saint Joseph', '07' => 'Saint Lucy', '08' => 'Saint Michael', '09' => 'Saint Peter', '10' => 'Saint Philip', '11' => 'Saint Thomas'], 'BD' => ['81' => 'Dhaka', '82' => 'Khulna', '83' => 'Rajshahi', '84' => 'Chittagong', '85' => 'Barisal', '86' => 'Sylhet'], 'BE' => ['01' => 'Antwerpen', '03' => 'Hainaut', '04' => 'Liege', '05' => 'Limburg', '06' => 'Luxembourg', '07' => 'Namur', '08' => 'Oost-Vlaanderen', '09' => 'West-Vlaanderen', '10' => 'Brabant wallon', '11' => 'Brussels Hoofdstedelijk Gewest', '12' => 'Vlaams-Brabant'], 'BF' => ['15' => 'Bam', '19' => 'Boulkiemde', '20' => 'Ganzourgou', '21' => 'Gnagna', '28' => 'Kouritenga', '33' => 'Oudalan', '34' => 'Passore', '36' => 'Sanguie', '40' => 'Soum', '42' => 'Tapoa', '44' => 'Zoundweogo', '45' => 'Bale', '46' => 'Banwa', '47' => 'Bazega', '48' => 'Bougouriba', '49' => 'Boulgou', '50' => 'Gourma', '51' => 'Houet', '52' => 'Ioba', '53' => 'Kadiogo', '54' => 'Kenedougou', '55' => 'Comoe', '56' => 'Komondjari', '57' => 'Kompienga', '58' => 'Kossi', '59' => 'Koulpelogo', '60' => 'Kourweogo', '61' => 'Leraba', '62' => 'Loroum', '63' => 'Mouhoun', '64' => 'Namentenga', '65' => 'Nahouri', '66' => 'Nayala', '67' => 'Noumbiel', '68' => 'Oubritenga', '69' => 'Poni', '70' => 'Sanmatenga', '71' => 'Seno', '72' => 'Sissili', '73' => 'Sourou', '74' => 'Tuy', '75' => 'Yagha', '76' => 'Yatenga', '77' => 'Ziro', '78' => 'Zondoma'], 'BG' => ['38' => 'Blagoevgrad', '39' => 'Burgas', '40' => 'Dobrich', '41' => 'Gabrovo', '42' => 'Sofia (stolitsa)', '43' => 'Haskovo', '44' => 'Kardzhali', '45' => 'Kyustendil', '46' => 'Lovech', '47' => 'Montana', '48' => 'Pazardzhik', '49' => 'Pernik', '50' => 'Pleven', '51' => 'Plovdiv', '52' => 'Razgrad', '53' => 'Ruse', '54' => 'Shumen', '55' => 'Silistra', '56' => 'Sliven', '57' => 'Smolyan', '58' => 'Sofia', '59' => 'Stara Zagora', '60' => 'Targovishte', '61' => 'Varna', '62' => 'Veliko Tarnovo', '63' => 'Vidin', '64' => 'Vratsa', '65' => 'Yambol'], 'BH' => ['15' => 'Al Muharraq', '16' => 'Al \'Asimah', '17' => 'Al Janubiyah', '18' => 'Ash Shamaliyah'], 'BI' => ['02' => 'Bujumbura Mairie', '09' => 'Bubanza', '10' => 'Bururi', '11' => 'Cankuzo', '12' => 'Cibitoke', '13' => 'Gitega', '14' => 'Karuzi', '15' => 'Kayanza', '16' => 'Kirundo', '17' => 'Makamba', '18' => 'Muyinga', '19' => 'Ngozi', '20' => 'Rutana', '21' => 'Ruyigi', '22' => 'Muramvya', '23' => 'Mwaro'], 'BJ' => ['07' => 'Alibori', '08' => 'Atacora', '09' => 'Atlantique', '10' => 'Borgou', '11' => 'Collines', '12' => 'Couffo', '13' => 'Donga', '14' => 'Littoral', '15' => 'Mono', '16' => 'Oueme', '17' => 'Plateau', '18' => 'Zou'], 'BM' => ['02' => 'Hamilton', '03' => 'Hamilton', '06' => 'Saint George'], 'BN' => ['08' => 'Belait', '09' => 'Brunei-Muara', '10' => 'Temburong', '15' => 'Tutong'], 'BO' => ['01' => 'Chuquisaca', '02' => 'Cochabamba', '03' => 'El Beni', '04' => 'La Paz', '05' => 'Oruro', '06' => 'Pando', '07' => 'Potosi', '08' => 'Santa Cruz', '09' => 'Tarija'], 'BR' => ['01' => 'Acre', '02' => 'Alagoas', '03' => 'Amapa', '04' => 'Amazonas', '05' => 'Bahia', '06' => 'Ceara', '07' => 'Distrito Federal', '08' => 'Espirito Santo', '11' => 'Mato Grosso do Sul', '13' => 'Maranhao', '14' => 'Mato Grosso', '15' => 'Minas Gerais', '16' => 'Para', '17' => 'Paraiba', '18' => 'Parana', '20' => 'Piaui', '21' => 'Rio de Janeiro', '22' => 'Rio Grande do Norte', '23' => 'Rio Grande do Sul', '24' => 'Rondonia', '25' => 'Roraima', '26' => 'Santa Catarina', '27' => 'Sao Paulo', '28' => 'Sergipe', '29' => 'Goias', '30' => 'Pernambuco', '31' => 'Tocantins'], 'BS' => ['15' => 'Long Island', '22' => 'Harbour Island', '23' => 'New Providence', '25' => 'City of Freeport', '26' => 'Central Andros', '29' => 'East Grand Bahama', '31' => 'Hope Town', '33' => 'South Eleuthera'], 'BT' => ['05' => 'Bumthang', '06' => 'Chhukha', '07' => 'Tsirang', '08' => 'Dagana', '10' => 'Haa', '11' => 'Lhuentse', '12' => 'Monggar', '13' => 'Paro', '14' => 'Pemagatshel', '15' => 'Punakha', '16' => 'Samtse', '17' => 'Samdrup Jongkhar', '18' => 'Zhemgang', '19' => 'Trashigang', '20' => 'Thimphu', '21' => 'Trongsa', '22' => 'Wangdue Phodrang'], 'BW' => ['01' => 'Central', '03' => 'Ghanzi', '04' => 'Kgalagadi', '05' => 'Kgatleng', '06' => 'Kweneng', '08' => 'North East', '09' => 'South East', '10' => 'Southern', '11' => 'North West'], 'BY' => ['01' => 'Brestskaya voblasts\'', '02' => 'Homyel\'skaya voblasts\'', '03' => 'Hrodzenskaya voblasts\'', '04' => 'Horad Minsk', '05' => 'Minskaya voblasts\'', '06' => 'Mahilyowskaya voblasts\'', '07' => 'Vitsyebskaya voblasts\''], 'BZ' => ['01' => 'Belize', '02' => 'Cayo', '03' => 'Corozal', '04' => 'Orange Walk', '05' => 'Stann Creek', '06' => 'Toledo'], 'CA' => ['AB' => 'Alberta', 'BC' => 'British Columbia', 'MB' => 'Manitoba', 'NB' => 'New Brunswick', 'NL' => 'Newfoundland and Labrador', 'NS' => 'Nova Scotia', 'NT' => 'Northwest Territories', 'NU' => 'Nunavut', 'ON' => 'Ontario', 'PE' => 'Prince Edward Island', 'QC' => 'Quebec', 'SK' => 'Saskatchewan', 'YT' => 'Yukon'], 'CD' => ['01' => 'Mai-Ndombe', '02' => 'Tshuapa', '04' => 'Sankuru', '05' => 'Tanganyika', '06' => 'Kinshasa', '08' => 'Kongo Central', '09' => 'Tshopo', '10' => 'Maniema', '11' => 'Nord-Kivu', '12' => 'Sud-Kivu'], 'CF' => ['01' => 'Bamingui-Bangoran', '02' => 'Basse-Kotto', '03' => 'Haute-Kotto', '04' => 'Mambere-Kadei', '05' => 'Haut-Mbomou', '06' => 'Kemo-Gribingui', '07' => 'Lobaye', '08' => 'Mbomou', '09' => 'Nana-Mambere', '11' => 'Ouaka', '12' => 'Ouham', '13' => 'Ouham-Pende', '14' => 'Vakaga', '15' => 'Gribingui', '16' => 'Sangha', '17' => 'Ombella-Mpoko', '18' => 'Bangui'], 'CG' => ['01' => 'Bouenza', '04' => 'Pointe-Noire', '05' => 'Lekoumou', '06' => 'Likouala', '07' => 'Niari', '08' => 'Plateaux', '10' => 'Sangha', '11' => 'Pool', '12' => 'Brazzaville', '13' => 'Cuvette', '14' => 'Cuvette-Ouest'], 'CH' => ['01' => 'Aargau', '02' => 'Appenzell Ausserrhoden', '03' => 'Basel-Landschaft', '04' => 'Basel-Stadt', '05' => 'Bern', '06' => 'Fribourg', '07' => 'Geneve', '08' => 'Glarus', '09' => 'Graubunden', '10' => 'Appenzell Innerrhoden', '11' => 'Luzern', '12' => 'Neuchatel', '13' => 'Nidwalden', '14' => 'Obwalden', '15' => 'Sankt Gallen', '16' => 'Schaffhausen', '17' => 'Schwyz', '18' => 'Solothurn', '19' => 'Thurgau', '20' => 'Ticino', '21' => 'Uri', '22' => 'Valais', '23' => 'Vaud', '24' => 'Zug', '25' => 'Zurich', '26' => 'Jura'], 'CI' => ['74' => 'Lagunes', '75' => 'Woroba', '76' => 'Bas-Sassandra', '77' => 'Denguele', '78' => 'Montagnes', '79' => 'Goh-Djiboua', '80' => 'Sassandra-Marahoue', '81' => 'Lacs', '82' => 'Lagunes', '83' => 'Sassandra-Marahoue', '84' => 'Montagnes', '85' => 'Comoe', '86' => 'Lacs', '87' => 'Savanes', '88' => 'Goh-Djiboua', '89' => 'Comoe', '90' => 'Vallee du Bandama', '91' => 'Woroba', '92' => 'Zanzan'], 'CL' => ['01' => 'Valparaiso', '02' => 'Aisen del General Carlos Ibanez del Campo', '03' => 'Antofagasta', '04' => 'La Araucania', '05' => 'Atacama', '06' => 'Biobio', '07' => 'Coquimbo', '08' => 'Libertador General Bernardo O\'Higgins', '09' => 'Los Lagos', '10' => 'Magallanes', '11' => 'Maule', '12' => 'Region Metropolitana de Santiago', '13' => 'Tarapaca', '14' => 'Los Lagos', '15' => 'Tarapaca', '16' => 'Arica y Parinacota', '17' => 'Los Rios'], 'CM' => ['04' => 'Est', '05' => 'Littoral', '07' => 'Nord-Ouest', '08' => 'Ouest', '09' => 'Sud-Ouest', '10' => 'Adamaoua', '11' => 'Centre', '12' => 'Extreme-Nord', '13' => 'Nord', '14' => 'Sud'], 'CN' => ['01' => 'Anhui', '02' => 'Zhejiang', '03' => 'Jiangxi', '04' => 'Jiangsu', '05' => 'Jilin', '06' => 'Qinghai', '07' => 'Fujian', '08' => 'Heilongjiang', '09' => 'Henan', '10' => 'Hebei', '11' => 'Hunan', '12' => 'Hubei', '13' => 'Xinjiang', '14' => 'Xizang', '15' => 'Gansu', '16' => 'Guangxi', '18' => 'Guizhou', '19' => 'Liaoning', '20' => 'Nei Mongol', '21' => 'Ningxia', '22' => 'Beijing', '23' => 'Shanghai', '24' => 'Shanxi', '25' => 'Shandong', '26' => 'Shaanxi', '28' => 'Tianjin', '29' => 'Yunnan', '30' => 'Guangdong', '31' => 'Hainan', '32' => 'Sichuan', '33' => 'Chongqing'], 'CO' => ['01' => 'Amazonas', '02' => 'Antioquia', '03' => 'Arauca', '04' => 'Atlantico', '08' => 'Caqueta', '09' => 'Cauca', '10' => 'Cesar', '11' => 'Choco', '12' => 'Cordoba', '14' => 'Guaviare', '15' => 'Guainia', '16' => 'Huila', '17' => 'La Guajira', '19' => 'Meta', '20' => 'Narino', '21' => 'Norte de Santander', '22' => 'Putumayo', '23' => 'Quindio', '24' => 'Risaralda', '25' => 'San Andres, Providencia y Santa Catalina', '26' => 'Santander', '27' => 'Sucre', '28' => 'Tolima', '29' => 'Valle del Cauca', '30' => 'Vaupes', '31' => 'Vichada', '32' => 'Casanare', '33' => 'Cundinamarca', '34' => 'Distrito Capital de Bogota', '35' => 'Bolivar', '36' => 'Boyaca', '37' => 'Caldas', '38' => 'Magdalena'], 'CR' => ['01' => 'Alajuela', '02' => 'Cartago', '03' => 'Guanacaste', '04' => 'Heredia', '06' => 'Limon', '07' => 'Puntarenas', '08' => 'San Jose'], 'CU' => ['01' => 'Pinar del Rio', '02' => 'La Habana', '03' => 'Matanzas', '04' => 'Isla de la Juventud', '05' => 'Camaguey', '07' => 'Ciego de Avila', '08' => 'Cienfuegos', '09' => 'Granma', '10' => 'Guantanamo', '11' => 'Mayabeque', '12' => 'Holguin', '13' => 'Las Tunas', '14' => 'Sancti Spiritus', '15' => 'Santiago de Cuba', '16' => 'Villa Clara'], 'CV' => ['01' => 'Boa Vista', '02' => 'Brava', '04' => 'Maio', '05' => 'Paul', '07' => 'Ribeira Grande', '08' => 'Sal', '10' => 'Tarrafal de Sao Nicolau', '11' => 'Sao Vicente', '13' => 'Mosteiros', '14' => 'Praia', '15' => 'Santa Catarina', '16' => 'Santa Cruz', '17' => 'Sao Domingos', '18' => 'Sao Filipe', '19' => 'Sao Miguel', '20' => 'Tarrafal'], 'CY' => ['01' => 'Ammochostos', '02' => 'Keryneia', '03' => 'Larnaka', '04' => 'Lefkosia', '05' => 'Lemesos', '06' => 'Pafos'], 'CZ' => ['52' => 'Praha, Hlavni mesto', '78' => 'Jihomoravsky kraj', '79' => 'Jihocesky kraj', '80' => 'Kraj Vysocina', '81' => 'Karlovarsky kraj', '82' => 'Kralovehradecky kraj', '83' => 'Liberecky kraj', '84' => 'Olomoucky kraj', '85' => 'Moravskoslezsky kraj', '86' => 'Pardubicky kraj', '87' => 'Plzensky kraj', '88' => 'Stredocesky kraj', '89' => 'Ustecky kraj', '90' => 'Zlinsky kraj'], 'DE' => ['01' => 'Baden-Wurttemberg', '02' => 'Bayern', '03' => 'Bremen', '04' => 'Hamburg', '05' => 'Hessen', '06' => 'Niedersachsen', '07' => 'Nordrhein-Westfalen', '08' => 'Rheinland-Pfalz', '09' => 'Saarland', '10' => 'Schleswig-Holstein', '11' => 'Brandenburg', '12' => 'Mecklenburg-Vorpommern', '13' => 'Sachsen', '14' => 'Sachsen-Anhalt', '15' => 'Thuringen', '16' => 'Berlin'], 'DJ' => ['01' => 'Ali Sabieh', '04' => 'Obock', '05' => 'Tadjourah', '06' => 'Dikhil', '07' => 'Djibouti', '08' => 'Arta'], 'DK' => ['17' => 'Hovedstaden', '18' => 'Midtjylland', '19' => 'Nordjylland', '20' => 'Sjaelland', '21' => 'Syddanmark'], 'DM' => ['02' => 'Saint Andrew', '03' => 'Saint David', '04' => 'Saint George', '05' => 'Saint John', '06' => 'Saint Joseph', '07' => 'Saint Luke', '08' => 'Saint Mark', '09' => 'Saint Patrick', '10' => 'Saint Paul', '11' => 'Saint Peter'], 'DO' => ['01' => 'Azua', '02' => 'Baoruco', '03' => 'Barahona', '04' => 'Dajabon', '05' => 'Distrito Nacional (Santo Domingo)', '06' => 'Duarte', '08' => 'Espaillat', '09' => 'Independencia', '10' => 'La Altagracia', '11' => 'Elias Pina', '12' => 'La Romana', '14' => 'Maria Trinidad Sanchez', '15' => 'Monte Cristi', '16' => 'Pedernales', '17' => 'Peravia', '18' => 'Puerto Plata', '19' => 'Hermanas Mirabal', '20' => 'Samana', '21' => 'Sanchez Ramirez', '23' => 'San Juan', '24' => 'San Pedro de Macoris', '25' => 'Santiago', '26' => 'Santiago Rodriguez', '27' => 'Valverde', '28' => 'El Seibo', '29' => 'Hato Mayor', '30' => 'La Vega', '31' => 'Monsenor Nouel', '32' => 'Monte Plata', '33' => 'San Cristobal', '34' => 'Distrito Nacional (Santo Domingo)', '35' => 'Peravia', '36' => 'San Jose de Ocoa', '37' => 'Distrito Nacional (Santo Domingo)'], 'DZ' => ['01' => 'Alger', '03' => 'Batna', '04' => 'Constantine', '06' => 'Medea', '07' => 'Mostaganem', '09' => 'Oran', '10' => 'Saida', '12' => 'Setif', '13' => 'Tiaret', '14' => 'Tizi Ouzou', '15' => 'Tlemcen', '18' => 'Bejaia', '19' => 'Biskra', '20' => 'Blida', '21' => 'Bouira', '22' => 'Djelfa', '23' => 'Guelma', '24' => 'Jijel', '25' => 'Laghouat', '26' => 'Mascara', '27' => 'M\'sila', '29' => 'Oum el Bouaghi', '30' => 'Sidi Bel Abbes', '31' => 'Skikda', '33' => 'Tebessa', '34' => 'Adrar', '35' => 'Ain Defla', '36' => 'Ain Temouchent', '37' => 'Annaba', '38' => 'Bechar', '39' => 'Bordj Bou Arreridj', '40' => 'Boumerdes', '41' => 'Chlef', '42' => 'El Bayadh', '43' => 'El Oued', '44' => 'El Tarf', '45' => 'Ghardaia', '46' => 'Illizi', '47' => 'Khenchela', '48' => 'Mila', '49' => 'Naama', '50' => 'Ouargla', '51' => 'Relizane', '52' => 'Souk Ahras', '53' => 'Tamanrasset', '54' => 'Tindouf', '55' => 'Tipaza', '56' => 'Tissemsilt'], 'EC' => ['01' => 'Galapagos', '02' => 'Azuay', '03' => 'Bolivar', '04' => 'Canar', '05' => 'Carchi', '06' => 'Chimborazo', '07' => 'Cotopaxi', '08' => 'El Oro', '09' => 'Esmeraldas', '10' => 'Guayas', '11' => 'Imbabura', '12' => 'Loja', '13' => 'Los Rios', '14' => 'Manabi', '15' => 'Morona Santiago', '17' => 'Pastaza', '18' => 'Pichincha', '19' => 'Tungurahua', '20' => 'Zamora Chinchipe', '22' => 'Sucumbios', '23' => 'Napo', '24' => 'Orellana'], 'EE' => ['01' => 'Harjumaa', '02' => 'Hiiumaa', '03' => 'Ida-Virumaa', '04' => 'Jarvamaa', '05' => 'Jogevamaa', '06' => 'Ida-Virumaa', '07' => 'Laanemaa', '08' => 'Laane-Virumaa', '09' => 'Ida-Virumaa', '10' => 'Parnumaa', '11' => 'Parnumaa', '12' => 'Polvamaa', '13' => 'Raplamaa', '14' => 'Saaremaa', '15' => 'Ida-Virumaa', '16' => 'Harjumaa', '17' => 'Tartumaa', '18' => 'Tartumaa', '19' => 'Valgamaa', '20' => 'Viljandimaa', '21' => 'Vorumaa'], 'EG' => ['01' => 'Ad Daqahliyah', '02' => 'Al Bahr al Ahmar', '03' => 'Al Buhayrah', '04' => 'Al Fayyum', '05' => 'Al Gharbiyah', '06' => 'Al Iskandariyah', '07' => 'Al Isma\'iliyah', '08' => 'Al Jizah', '09' => 'Al Minufiyah', '10' => 'Al Minya', '11' => 'Al Qahirah', '12' => 'Al Qalyubiyah', '13' => 'Al Wadi al Jadid', '14' => 'Ash Sharqiyah', '15' => 'As Suways', '16' => 'Aswan', '17' => 'Asyut', '18' => 'Bani Suwayf', '19' => 'Bur Sa\'id', '20' => 'Dumyat', '21' => 'Kafr ash Shaykh', '22' => 'Matruh', '23' => 'Al Uqsur', '24' => 'Suhaj', '26' => 'Janub Sina\'', '27' => 'Shamal Sina\''], 'ER' => ['01' => 'Ansaba', '02' => 'Al Janubi', '03' => 'Janubi al Bahri al Ahmar', '04' => 'Qash-Barkah', '05' => 'Al Awsat', '06' => 'Shimali al Bahri al Ahmar'], 'ES' => ['07' => 'Illes Balears', '27' => 'La Rioja', '29' => 'Madrid, Comunidad de', '31' => 'Murcia, Region de', '32' => 'Navarra, Comunidad Foral de', '34' => 'Asturias, Principado de', '39' => 'Cantabria', '51' => 'Andalucia', '52' => 'Aragon', '53' => 'Canarias', '54' => 'Castilla-La Mancha', '55' => 'Castilla y Leon', '56' => 'Catalunya', '57' => 'Extremadura', '58' => 'Galicia', '59' => 'Pais Vasco', '60' => 'Valenciana, Comunidad'], 'ET' => ['44' => 'Adis Abeba', '45' => 'Afar', '46' => 'Amara', '47' => 'Binshangul Gumuz', '48' => 'Dire Dawa', '49' => 'Gambela Hizboch', '50' => 'Hareri Hizb', '51' => 'Oromiya', '52' => 'Sumale', '53' => 'Tigray', '54' => 'YeDebub Biheroch Bihereseboch na Hizboch'], 'FI' => ['08' => 'Pohjois-Pohjanmaa', '13' => 'Uusimaa', '14' => 'Pohjois-Savo', '15' => 'Varsinais-Suomi'], 'FJ' => ['01' => 'Central', '02' => 'Eastern', '03' => 'Northern', '04' => 'Rotuma', '05' => 'Western'], 'FM' => ['01' => 'Kosrae', '02' => 'Pohnpei', '03' => 'Chuuk', '04' => 'Yap'], 'FR' => ['97' => 'Nouvelle-Aquitaine', '98' => 'Auvergne-Rhone-Alpes', '99' => 'Normandie', 'A1' => 'Bourgogne-Franche-Comte', 'A2' => 'Bretagne', 'A3' => 'Centre-Val de Loire', 'A4' => 'Grand-Est', 'A5' => 'Corse', 'A6' => 'Bourgogne-Franche-Comte', 'A7' => 'Normandie', 'A8' => 'Ile-de-France', 'A9' => 'Occitanie', 'B1' => 'Nouvelle-Aquitaine', 'B2' => 'Grand-Est', 'B3' => 'Occitanie', 'B4' => 'Hauts-de-France', 'B5' => 'Pays-de-la-Loire', 'B6' => 'Hauts-de-France', 'B7' => 'Nouvelle-Aquitaine', 'B8' => 'Provence-Alpes-Cote-d\'Azur', 'B9' => 'Auvergne-Rhone-Alpes', 'C1' => 'Grand-Est'], 'GA' => ['01' => 'Estuaire', '02' => 'Haut-Ogooue', '03' => 'Moyen-Ogooue', '04' => 'Ngounie', '05' => 'Nyanga', '06' => 'Ogooue-Ivindo', '07' => 'Ogooue-Lolo', '08' => 'Ogooue-Maritime', '09' => 'Woleu-Ntem'], 'GB' => ['A1' => 'England', 'A2' => 'England', 'A3' => 'England', 'A4' => 'England', 'A5' => 'England', 'A6' => 'England', 'A7' => 'England', 'A8' => 'England', 'A9' => 'England', 'B1' => 'England', 'B2' => 'England', 'B3' => 'England', 'B4' => 'England', 'B5' => 'England', 'B6' => 'England', 'B7' => 'England', 'B8' => 'England', 'B9' => 'England', 'C1' => 'England', 'C2' => 'England', 'C3' => 'England', 'C4' => 'England', 'C5' => 'England', 'C6' => 'England', 'C7' => 'England', 'C8' => 'England', 'C9' => 'England', 'D1' => 'England', 'D2' => 'England', 'D3' => 'England', 'D4' => 'England', 'D5' => 'England', 'D6' => 'England', 'D7' => 'England', 'D8' => 'England', 'D9' => 'England', 'E1' => 'England', 'E2' => 'England', 'E3' => 'England', 'E4' => 'England', 'E5' => 'England', 'E6' => 'England', 'E7' => 'England', 'E8' => 'England', 'E9' => 'England', 'F1' => 'England', 'F2' => 'England', 'F3' => 'England', 'F4' => 'England', 'F5' => 'England', 'F6' => 'England', 'F7' => 'England', 'F8' => 'England', 'F9' => 'England', 'G1' => 'England', 'G2' => 'England', 'G3' => 'England', 'G4' => 'England', 'G5' => 'England', 'G6' => 'England', 'G7' => 'England', 'Q6' => 'Northern Ireland', 'Q7' => 'Northern Ireland', 'Q8' => 'Northern Ireland', 'Q9' => 'Northern Ireland', 'R1' => 'Northern Ireland', 'R2' => 'Northern Ireland', 'R3' => 'Northern Ireland', 'R4' => 'Northern Ireland', 'R5' => 'Northern Ireland', 'R6' => 'Northern Ireland', 'R7' => 'Northern Ireland', 'R8' => 'Northern Ireland', 'R9' => 'Northern Ireland', 'S1' => 'Northern Ireland', 'S2' => 'Northern Ireland', 'S3' => 'Northern Ireland', 'S4' => 'Northern Ireland', 'S5' => 'Northern Ireland', 'S6' => 'Northern Ireland', 'S7' => 'Northern Ireland', 'S8' => 'Northern Ireland', 'S9' => 'Northern Ireland', 'T1' => 'Northern Ireland', 'T2' => 'Northern Ireland', 'T3' => 'Northern Ireland', 'T4' => 'Northern Ireland', 'T5' => 'Scotland', 'T6' => 'Scotland', 'T7' => 'Scotland', 'T8' => 'Scotland', 'T9' => 'Scotland', 'U1' => 'Scotland', 'U2' => 'Scotland', 'U3' => 'Scotland', 'U4' => 'Scotland', 'U5' => 'Scotland', 'U6' => 'Scotland', 'U7' => 'Scotland', 'U8' => 'Scotland', 'U9' => 'Scotland', 'V1' => 'Scotland', 'V2' => 'Scotland', 'V3' => 'Scotland', 'V4' => 'Scotland', 'V5' => 'Scotland', 'V6' => 'Scotland', 'V7' => 'Scotland', 'V8' => 'Scotland', 'V9' => 'Scotland', 'W1' => 'Scotland', 'W2' => 'Scotland', 'W3' => 'Scotland', 'W4' => 'Scotland', 'W5' => 'Scotland', 'W6' => 'Scotland', 'W7' => 'Scotland', 'W8' => 'Scotland', 'W9' => 'Scotland', 'X1' => 'Wales', 'X2' => 'Wales', 'X3' => 'Wales', 'X4' => 'Wales', 'X5' => 'Wales', 'X6' => 'Wales', 'X7' => 'Wales', 'X8' => 'Wales', 'X9' => 'Wales', 'Y1' => 'Wales', 'Y2' => 'Wales', 'Y3' => 'Wales', 'Y4' => 'Wales', 'Y5' => 'Wales', 'Y6' => 'Wales', 'Y7' => 'Wales', 'Y8' => 'Wales', 'Y9' => 'Wales', 'Z1' => 'Wales', 'Z2' => 'Wales', 'Z3' => 'Wales', 'Z4' => 'Wales'], 'GD' => ['01' => 'Saint Andrew', '02' => 'Saint David', '03' => 'Saint George', '04' => 'Saint John', '05' => 'Saint Mark', '06' => 'Saint Patrick'], 'GE' => ['01' => 'Samegrelo-Zemo Svaneti', '02' => 'Abkhazia', '03' => 'Samtskhe-Javakheti', '04' => 'Ajaria', '05' => 'Mtskheta-Mtianeti', '06' => 'Samtskhe-Javakheti', '07' => 'Samtskhe-Javakheti', '08' => 'K\'akheti', '09' => 'Rach\'a-Lechkhumi-Kvemo Svaneti', '10' => 'Samtskhe-Javakheti', '11' => 'Imereti', '12' => 'Kvemo Kartli', '13' => 'Samtskhe-Javakheti', '14' => 'Imereti', '15' => 'Samegrelo-Zemo Svaneti', '16' => 'Guria', '17' => 'K\'akheti', '18' => 'Kvemo Kartli', '19' => 'Mtskheta-Mtianeti', '20' => 'Kvemo Kartli', '21' => 'Shida Kartli', '22' => 'Shida Kartli', '23' => 'K\'akheti', '24' => 'Shida Kartli', '25' => 'Shida Kartli', '26' => 'Shida Kartli', '27' => 'Imereti', '28' => 'Shida Kartli', '29' => 'Samegrelo-Zemo Svaneti', '30' => 'Imereti', '31' => 'Imereti', '32' => 'K\'akheti', '33' => 'Guria', '34' => 'Rach\'a-Lechkhumi-Kvemo Svaneti', '35' => 'Kvemo Kartli', '36' => 'Samegrelo-Zemo Svaneti', '37' => 'Samegrelo-Zemo Svaneti', '38' => 'Mtskheta-Mtianeti', '39' => 'Samtskhe-Javakheti', '40' => 'Rach\'a-Lechkhumi-Kvemo Svaneti', '41' => 'Guria', '42' => 'Samegrelo-Zemo Svaneti', '43' => 'Mtskheta-Mtianeti', '44' => 'K\'akheti', '45' => 'Kvemo Kartli', '46' => 'Imereti', '47' => 'K\'akheti', '48' => 'Imereti', '49' => 'Samegrelo-Zemo Svaneti', '50' => 'K\'akheti', '51' => 'Tbilisi', '52' => 'K\'akheti', '53' => 'Imereti', '54' => 'Kvemo Kartli', '55' => 'Mtskheta-Mtianeti', '56' => 'Imereti', '57' => 'Rach\'a-Lechkhumi-Kvemo Svaneti', '58' => 'Samegrelo-Zemo Svaneti', '59' => 'Kvemo Kartli', '60' => 'Imereti', '61' => 'Imereti', '62' => 'Imereti', '63' => 'Samegrelo-Zemo Svaneti', '64' => 'Samegrelo-Zemo Svaneti'], 'GH' => ['01' => 'Greater Accra', '02' => 'Ashanti', '03' => 'Brong-Ahafo', '04' => 'Central', '05' => 'Eastern', '06' => 'Northern', '08' => 'Volta', '09' => 'Western', '10' => 'Upper East', '11' => 'Upper West'], 'GL' => ['03' => 'Kommune Qeqertalik'], 'GM' => ['01' => 'Banjul', '02' => 'Lower River', '03' => 'Central River', '04' => 'Upper River', '05' => 'Western', '07' => 'North Bank'], 'GN' => ['01' => 'Beyla', '02' => 'Boffa', '03' => 'Boke', '04' => 'Conakry', '05' => 'Dabola', '06' => 'Dalaba', '07' => 'Dinguiraye', '09' => 'Faranah', '10' => 'Forecariah', '11' => 'Fria', '12' => 'Gaoual', '13' => 'Guekedou', '15' => 'Kerouane', '16' => 'Kindia', '17' => 'Kissidougou', '18' => 'Koundara', '19' => 'Kouroussa', '21' => 'Macenta', '22' => 'Mali', '23' => 'Mamou', '25' => 'Pita', '27' => 'Telimele', '28' => 'Tougue', '29' => 'Yomou', '30' => 'Coyah', '31' => 'Dubreka', '32' => 'Kankan', '33' => 'Koubia', '34' => 'Labe', '35' => 'Lelouma', '36' => 'Lola', '37' => 'Mandiana', '38' => 'Nzerekore', '39' => 'Siguiri'], 'GQ' => ['03' => 'Annobon', '04' => 'Bioko Norte', '05' => 'Bioko Sur', '06' => 'Centro Sur', '07' => 'Kie-Ntem', '08' => 'Litoral', '09' => 'Wele-Nzas'], 'GR' => ['01' => 'Anatoliki Makedonia kai Thraki', '02' => 'Anatoliki Makedonia kai Thraki', '03' => 'Anatoliki Makedonia kai Thraki', '04' => 'Anatoliki Makedonia kai Thraki', '05' => 'Kentriki Makedonia', '06' => 'Kentriki Makedonia', '07' => 'Kentriki Makedonia', '08' => 'Dytiki Makedonia', '09' => 'Dytiki Makedonia', '10' => 'Dytiki Makedonia', '11' => 'Dytiki Makedonia', '12' => 'Kentriki Makedonia', '13' => 'Kentriki Makedonia', '14' => 'Anatoliki Makedonia kai Thraki', '15' => 'Kentriki Makedonia', '16' => 'Kentriki Makedonia', '17' => 'Ipeiros', '18' => 'Ipeiros', '19' => 'Ipeiros', '20' => 'Ipeiros', '21' => 'Thessalia', '22' => 'Thessalia', '23' => 'Thessalia', '24' => 'Thessalia', '25' => 'Ionia Nisia', '26' => 'Ionia Nisia', '27' => 'Ionia Nisia', '28' => 'Ionia Nisia', '29' => 'Sterea Ellada', '30' => 'Sterea Ellada', '31' => 'Dytiki Ellada', '32' => 'Sterea Ellada', '33' => 'Sterea Ellada', '34' => 'Sterea Ellada', '35' => 'Attiki', '36' => 'Peloponnisos', '37' => 'Peloponnisos', '38' => 'Dytiki Ellada', '39' => 'Dytiki Ellada', '40' => 'Peloponnisos', '41' => 'Peloponnisos', '42' => 'Peloponnisos', '43' => 'Kriti', '44' => 'Kriti', '45' => 'Kriti', '46' => 'Kriti', '47' => 'Notio Aigaio', '48' => 'Voreio Aigaio', '49' => 'Notio Aigaio', '50' => 'Voreio Aigaio', '51' => 'Voreio Aigaio'], 'GT' => ['01' => 'Alta Verapaz', '02' => 'Baja Verapaz', '03' => 'Chimaltenango', '04' => 'Chiquimula', '05' => 'El Progreso', '06' => 'Escuintla', '07' => 'Guatemala', '08' => 'Huehuetenango', '09' => 'Izabal', '10' => 'Jalapa', '11' => 'Jutiapa', '12' => 'Peten', '13' => 'Quetzaltenango', '14' => 'Quiche', '15' => 'Retalhuleu', '16' => 'Sacatepequez', '17' => 'San Marcos', '18' => 'Santa Rosa', '19' => 'Solola', '20' => 'Suchitepequez', '21' => 'Totonicapan', '22' => 'Zacapa'], 'GW' => ['01' => 'Bafata', '02' => 'Quinara', '04' => 'Oio', '05' => 'Bolama', '06' => 'Cacheu', '07' => 'Tombali', '10' => 'Gabu', '11' => 'Bissau', '12' => 'Biombo'], 'GY' => ['10' => 'Barima-Waini', '11' => 'Cuyuni-Mazaruni', '12' => 'Demerara-Mahaica', '13' => 'East Berbice-Corentyne', '14' => 'Essequibo Islands-West Demerara', '15' => 'Mahaica-Berbice', '16' => 'Pomeroon-Supenaam', '17' => 'Potaro-Siparuni', '18' => 'Upper Demerara-Berbice', '19' => 'Upper Takutu-Upper Essequibo'], 'HN' => ['01' => 'Atlantida', '02' => 'Choluteca', '03' => 'Colon', '04' => 'Comayagua', '05' => 'Copan', '06' => 'Cortes', '07' => 'El Paraiso', '08' => 'Francisco Morazan', '09' => 'Gracias a Dios', '10' => 'Intibuca', '11' => 'Islas de la Bahia', '12' => 'La Paz', '13' => 'Lempira', '14' => 'Ocotepeque', '15' => 'Olancho', '16' => 'Santa Barbara', '17' => 'Valle', '18' => 'Yoro'], 'HR' => ['01' => 'Bjelovarsko-bilogorska zupanija', '02' => 'Brodsko-posavska zupanija', '03' => 'Dubrovacko-neretvanska zupanija', '04' => 'Istarska zupanija', '05' => 'Karlovacka zupanija', '06' => 'Koprivnicko-krizevacka zupanija', '07' => 'Krapinsko-zagorska zupanija', '08' => 'Licko-senjska zupanija', '09' => 'Medimurska zupanija', '10' => 'Osjecko-baranjska zupanija', '11' => 'Pozesko-slavonska zupanija', '12' => 'Primorsko-goranska zupanija', '13' => 'Sibensko-kninska zupanija', '14' => 'Sisacko-moslavacka zupanija', '15' => 'Splitsko-dalmatinska zupanija', '16' => 'Varazdinska zupanija', '17' => 'Viroviticko-podravska zupanija', '18' => 'Vukovarsko-srijemska zupanija', '19' => 'Zadarska zupanija', '20' => 'Zagrebacka zupanija', '21' => 'Grad Zagreb'], 'HT' => ['03' => 'Nord-Ouest', '06' => 'Artibonite', '07' => 'Centre', '09' => 'Nord', '10' => 'Nord-Est', '11' => 'Ouest', '12' => 'Sud', '13' => 'Sud-Est', '14' => 'Grande\'Anse', '15' => 'Nippes'], 'HU' => ['01' => 'Bacs-Kiskun', '02' => 'Baranya', '03' => 'Bekes', '04' => 'Borsod-Abauj-Zemplen', '05' => 'Budapest', '06' => 'Csongrad', '07' => 'Hajdu-Bihar', '08' => 'Fejer', '09' => 'Gyor-Moson-Sopron', '10' => 'Hajdu-Bihar', '11' => 'Heves', '12' => 'Komarom-Esztergom', '13' => 'Borsod-Abauj-Zemplen', '14' => 'Nograd', '15' => 'Baranya', '16' => 'Pest', '17' => 'Somogy', '18' => 'Szabolcs-Szatmar-Bereg', '19' => 'Csongrad', '20' => 'Jasz-Nagykun-Szolnok', '21' => 'Tolna', '22' => 'Vas', '23' => 'Veszprem', '24' => 'Zala', '25' => 'Gyor-Moson-Sopron', '26' => 'Bekes', '27' => 'Fejer', '28' => 'Heves', '29' => 'Csongrad', '30' => 'Somogy', '31' => 'Bacs-Kiskun', '32' => 'Zala', '33' => 'Szabolcs-Szatmar-Bereg', '34' => 'Gyor-Moson-Sopron', '35' => 'Fejer', '36' => 'Jasz-Nagykun-Szolnok', '37' => 'Vas', '38' => 'Komarom-Esztergom', '39' => 'Veszprem', '40' => 'Zala', '41' => 'Nograd', '42' => 'Tolna', '43' => 'Pest'], 'ID' => ['01' => 'Aceh', '02' => 'Bali', '03' => 'Bengkulu', '04' => 'Jakarta Raya', '05' => 'Jambi', '07' => 'Jawa Tengah', '08' => 'Jawa Timur', '10' => 'Yogyakarta', '11' => 'Kalimantan Barat', '12' => 'Kalimantan Selatan', '13' => 'Kalimantan Tengah', '14' => 'Kalimantan Timur', '15' => 'Lampung', '17' => 'Nusa Tenggara Barat', '18' => 'Nusa Tenggara Timur', '21' => 'Sulawesi Tengah', '22' => 'Sulawesi Tenggara', '24' => 'Sumatera Barat', '26' => 'Sumatera Utara', '28' => 'Maluku', '29' => 'Maluku Utara', '30' => 'Jawa Barat', '31' => 'Sulawesi Utara', '32' => 'Sumatera Selatan', '33' => 'Banten', '34' => 'Gorontalo', '35' => 'Kepulauan Bangka Belitung', '36' => 'Papua', '37' => 'Riau', '38' => 'Sulawesi Selatan', '39' => 'Papua Barat', '40' => 'Kepulauan Riau', '41' => 'Sulawesi Barat'], 'IE' => ['01' => 'Carlow', '02' => 'Cavan', '03' => 'Clare', '04' => 'Cork', '06' => 'Donegal', '07' => 'Dublin', '10' => 'Galway', '11' => 'Kerry', '12' => 'Kildare', '13' => 'Kilkenny', '14' => 'Leitrim', '15' => 'Laois', '16' => 'Limerick', '18' => 'Longford', '19' => 'Louth', '20' => 'Mayo', '21' => 'Meath', '22' => 'Monaghan', '23' => 'Offaly', '24' => 'Roscommon', '25' => 'Sligo', '26' => 'Tipperary', '27' => 'Waterford', '29' => 'Westmeath', '30' => 'Wexford', '31' => 'Wicklow'], 'IL' => ['01' => 'HaDarom', '02' => 'HaMerkaz', '03' => 'HaTsafon', '04' => 'Hefa', '05' => 'Tel Aviv', '06' => 'Yerushalayim'], 'IN' => ['01' => 'Andaman and Nicobar Islands', '02' => 'Andhra Pradesh', '03' => 'Assam', '05' => 'Chandigarh', '06' => 'Dadra and Nagar Haveli', '07' => 'Delhi', '09' => 'Gujarat', '10' => 'Haryana', '11' => 'Himachal Pradesh', '12' => 'Jammu and Kashmir', '13' => 'Kerala', '14' => 'Lakshadweep', '16' => 'Maharashtra', '17' => 'Manipur', '18' => 'Meghalaya', '19' => 'Karnataka', '20' => 'Nagaland', '21' => 'Odisha', '22' => 'Puducherry', '23' => 'Punjab', '24' => 'Rajasthan', '25' => 'Tamil Nadu', '26' => 'Tripura', '28' => 'West Bengal', '29' => 'Sikkim', '30' => 'Arunachal Pradesh', '31' => 'Mizoram', '32' => 'Daman and Diu', '33' => 'Goa', '34' => 'Bihar', '35' => 'Madhya Pradesh', '36' => 'Uttar Pradesh', '37' => 'Chhattisgarh', '38' => 'Jharkhand', '39' => 'Uttarakhand'], 'IQ' => ['01' => 'Al Anbar', '02' => 'Al Basrah', '03' => 'Al Muthanna', '04' => 'Al Qadisiyah', '05' => 'As Sulaymaniyah', '06' => 'Babil', '07' => 'Baghdad', '08' => 'Dahuk', '09' => 'Dhi Qar', '10' => 'Diyala', '11' => 'Arbil', '12' => 'Karbala\'', '13' => 'Kirkuk', '14' => 'Maysan', '15' => 'Ninawa', '16' => 'Wasit', '17' => 'An Najaf', '18' => 'Salah ad Din'], 'IR' => ['01' => 'Azarbayjan-e Gharbi', '03' => 'Chahar Mahal va Bakhtiari', '04' => 'Sistan va Baluchestan', '05' => 'Kohgiluyeh va Bowyer Ahmad', '07' => 'Fars', '08' => 'Gilan', '09' => 'Hamadan', '10' => 'Ilam', '11' => 'Hormozgan', '12' => 'Kerman', '13' => 'Kermanshah', '15' => 'Khuzestan', '16' => 'Kordestan', '17' => 'Mazandaran', '18' => 'Semnan', '19' => 'Markazi', '21' => 'Zanjan', '22' => 'Bushehr', '23' => 'Lorestan', '24' => 'Markazi', '25' => 'Semnan', '26' => 'Tehran', '27' => 'Zanjan', '28' => 'Esfahan', '29' => 'Kerman', '31' => 'Yazd', '32' => 'Ardabil', '33' => 'Azarbayjan-e Sharqi', '34' => 'Markazi', '35' => 'Mazandaran', '36' => 'Zanjan', '37' => 'Golestan', '38' => 'Qazvin', '39' => 'Qom', '40' => 'Yazd', '41' => 'Khorasan-e Jonubi', '42' => 'Khorasan-e Razavi', '43' => 'Khorasan-e Shomali', '44' => 'Alborz'], 'IS' => ['03' => 'Sudurland', '05' => 'Nordurland vestra', '06' => 'Austurland', '07' => 'Vesturland', '09' => 'Nordurland eystra', '10' => 'Sudurnes', '15' => 'Sudurnes', '17' => 'Vesturland', '20' => 'Austurland', '21' => 'Nordurland eystra', '23' => 'Sudurland', '28' => 'Nordurland vestra', '29' => 'Vesturland', '30' => 'Vestfirdir', '31' => 'Austurland', '32' => 'Nordurland vestra', '34' => 'Vestfirdir', '35' => 'Nordurland vestra', '36' => 'Vestfirdir', '37' => 'Sudurland', '38' => 'Austurland', '39' => 'Hofudborgarsvaedi', '40' => 'Nordurland eystra', '41' => 'Nordurland vestra', '42' => 'Sudurland', '43' => 'Sudurnes', '44' => 'Vestfirdir', '45' => 'Vesturland'], 'IT' => ['01' => 'Abruzzo', '02' => 'Basilicata', '03' => 'Calabria', '04' => 'Campania', '05' => 'Emilia-Romagna', '06' => 'Friuli-Venezia Giulia', '07' => 'Lazio', '08' => 'Liguria', '09' => 'Lombardia', '10' => 'Marche', '11' => 'Molise', '12' => 'Piemonte', '13' => 'Puglia', '14' => 'Sardegna', '15' => 'Sicilia', '16' => 'Toscana', '17' => 'Trentino-Alto Adige', '18' => 'Umbria', '19' => 'Valle d\'Aosta', '20' => 'Veneto'], 'JM' => ['01' => 'Clarendon', '02' => 'Hanover', '04' => 'Manchester', '07' => 'Portland', '08' => 'Saint Andrew', '09' => 'Saint Ann', '10' => 'Saint Catherine', '11' => 'Saint Elizabeth', '12' => 'Saint James', '13' => 'Saint Mary', '14' => 'Saint Thomas', '15' => 'Trelawny', '16' => 'Westmoreland', '17' => 'Kingston'], 'JO' => ['02' => 'Al Balqa\'', '09' => 'Al Karak', '12' => 'At Tafilah', '15' => 'Al Mafraq', '16' => 'Al \'Asimah', '17' => 'Az Zarqa\'', '18' => 'Irbid', '19' => 'Ma\'an', '20' => '\'Ajlun', '21' => 'Al \'Aqabah', '22' => 'Jarash', '23' => 'Madaba'], 'JP' => ['01' => 'Aichi', '02' => 'Akita', '03' => 'Aomori', '04' => 'Chiba', '05' => 'Ehime', '06' => 'Fukui', '07' => 'Fukuoka', '08' => 'Fukushima', '09' => 'Gifu', '10' => 'Gunma', '11' => 'Hiroshima', '12' => 'Hokkaido', '13' => 'Hyogo', '14' => 'Ibaraki', '15' => 'Ishikawa', '16' => 'Iwate', '17' => 'Kagawa', '18' => 'Kagoshima', '19' => 'Kanagawa', '20' => 'Kochi', '21' => 'Kumamoto', '22' => 'Kyoto', '23' => 'Mie', '24' => 'Miyagi', '25' => 'Miyazaki', '26' => 'Nagano', '27' => 'Nagasaki', '28' => 'Nara', '29' => 'Niigata', '30' => 'Oita', '31' => 'Okayama', '32' => 'Osaka', '33' => 'Saga', '34' => 'Saitama', '35' => 'Shiga', '36' => 'Shimane', '37' => 'Shizuoka', '38' => 'Tochigi', '39' => 'Tokushima', '40' => 'Tokyo', '41' => 'Tottori', '42' => 'Toyama', '43' => 'Wakayama', '44' => 'Yamagata', '45' => 'Yamaguchi', '46' => 'Yamanashi', '47' => 'Okinawa'], 'KE' => ['01' => 'Nyeri', '02' => 'Tana River', '03' => 'Tharaka-Nithi', '05' => 'Nairobi City', '06' => 'Wajir', '07' => 'Siaya', '08' => 'West Pokot', '09' => 'Vihiga'], 'KG' => ['01' => 'Bishkek', '02' => 'Chuy', '03' => 'Jalal-Abad', '04' => 'Naryn', '05' => 'Osh', '06' => 'Talas', '07' => 'Ysyk-Kol', '08' => 'Osh', '09' => 'Batken'], 'KH' => ['01' => 'Batdambang', '02' => 'Kampong Chaam', '03' => 'Kampong Chhnang', '04' => 'Kampong Spueu', '05' => 'Kampong Thum', '06' => 'Kampot', '07' => 'Kandaal', '08' => 'Kaoh Kong', '09' => 'Kracheh', '10' => 'Mondol Kiri', '11' => 'Phnom Penh', '12' => 'Pousaat', '13' => 'Preah Vihear', '14' => 'Prey Veaeng', '15' => 'Rotanak Kiri', '16' => 'Siem Reab', '17' => 'Stueng Traeng', '18' => 'Svaay Rieng', '19' => 'Taakaev', '25' => 'Banteay Mean Chey', '29' => 'Baat Dambang', '30' => 'Krong Pailin'], 'KI' => ['01' => 'Gilbert Islands', '02' => 'Line Islands'], 'KM' => ['01' => 'Anjouan', '02' => 'Grande Comore', '03' => 'Moheli'], 'KN' => ['01' => 'Christ Church Nichola Town', '02' => 'Saint Anne Sandy Point', '03' => 'Saint George Basseterre', '04' => 'Saint George Gingerland', '05' => 'Saint James Windward', '06' => 'Saint John Capisterre', '07' => 'Saint John Figtree', '08' => 'Saint Mary Cayon', '09' => 'Saint Paul Capisterre', '10' => 'Saint Paul Charlestown', '11' => 'Saint Peter Basseterre', '12' => 'Saint Thomas Lowland', '13' => 'Saint Thomas Middle Island', '15' => 'Trinity Palmetto Point'], 'KP' => ['01' => 'Chagang-do', '03' => 'Hamgyong-namdo', '06' => 'Hwanghae-namdo', '07' => 'Hwanghae-bukto', '08' => 'Hwanghae-bukto', '09' => 'Kangwon-do', '11' => 'P\'yongan-bukto', '12' => 'P\'yongyang', '13' => 'Ryanggang-do', '14' => 'P\'yongan-namdo', '15' => 'P\'yongan-namdo', '17' => 'Hamgyong-bukto', '18' => 'Rason'], 'KR' => ['01' => 'Jeju-teukbyeoljachido', '03' => 'Jeollabuk-do', '05' => 'Chungcheongbuk-do', '06' => 'Gangwon-do', '10' => 'Busan-gwangyeoksi', '11' => 'Seoul-teukbyeolsi', '12' => 'Incheon-gwangyeoksi', '13' => 'Gyeonggi-do', '14' => 'Gyeongsangbuk-do', '15' => 'Daegu-gwangyeoksi', '16' => 'Jeollanam-do', '17' => 'Chungcheongnam-do', '18' => 'Gwangju-gwangyeoksi', '19' => 'Daejeon-gwangyeoksi', '20' => 'Gyeongsangnam-do', '21' => 'Ulsan-gwangyeoksi'], 'KW' => ['01' => 'Al Ahmadi', '02' => 'Al \'Asimah', '05' => 'Al Jahra\'', '07' => 'Al Farwaniyah', '08' => 'Hawalli', '09' => 'Mubarak al Kabir'], 'KY' => ['01' => 'Cayman Islands', '02' => 'Cayman Islands', '03' => 'Cayman Islands', '04' => 'Cayman Islands', '05' => 'Cayman Islands', '06' => 'Cayman Islands', '07' => 'Cayman Islands', '08' => 'Cayman Islands'], 'KZ' => ['01' => 'Almaty oblysy', '02' => 'Almaty', '03' => 'Aqmola oblysy', '04' => 'Aqtobe oblysy', '05' => 'Astana', '06' => 'Atyrau oblysy', '07' => 'Batys Qazaqstan oblysy', '08' => 'Bayqongyr', '09' => 'Mangghystau oblysy', '10' => 'Ongtustik Qazaqstan oblysy', '11' => 'Pavlodar oblysy', '12' => 'Qaraghandy oblysy', '13' => 'Qostanay oblysy', '14' => 'Qyzylorda oblysy', '15' => 'Shyghys Qazaqstan oblysy', '16' => 'Soltustik Qazaqstan oblysy', '17' => 'Zhambyl oblysy'], 'LA' => ['01' => 'Attapu', '02' => 'Champasak', '03' => 'Houaphan', '04' => 'Khammouan', '05' => 'Louang Namtha', '07' => 'Oudomxai', '08' => 'Phongsali', '09' => 'Salavan', '10' => 'Savannakhet', '11' => 'Viangchan', '13' => 'Xaignabouli', '14' => 'Xiangkhouang', '17' => 'Louangphabang'], 'LB' => ['01' => 'Beqaa', '02' => 'Liban-Sud', '03' => 'Liban-Nord', '04' => 'Beyrouth', '05' => 'Mont-Liban', '06' => 'Liban-Sud', '07' => 'Nabatiye', '08' => 'Beqaa', '09' => 'Liban-Nord', '10' => 'Aakkar', '11' => 'Baalbek-Hermel'], 'LC' => ['01' => 'Anse la Raye', '03' => 'Castries', '04' => 'Choiseul', '05' => 'Dennery', '06' => 'Gros Islet', '07' => 'Laborie', '08' => 'Micoud', '09' => 'Soufriere', '10' => 'Vieux Fort'], 'LI' => ['01' => 'Balzers', '02' => 'Eschen', '03' => 'Gamprin', '04' => 'Mauren', '05' => 'Planken', '06' => 'Ruggell', '07' => 'Schaan', '08' => 'Schellenberg', '09' => 'Triesen', '10' => 'Triesenberg', '11' => 'Vaduz'], 'LK' => ['29' => 'Central Province', '30' => 'North Central Province', '32' => 'North Western Province', '33' => 'Sabaragamuwa Province', '34' => 'Southern Province', '35' => 'Uva Province', '36' => 'Western Province', '37' => 'Eastern Province', '38' => 'Northern Province'], 'LR' => ['01' => 'Bong', '04' => 'Grand Cape Mount', '05' => 'Lofa', '06' => 'Maryland', '07' => 'Montserrado', '09' => 'Nimba', '10' => 'Sinoe', '11' => 'Grand Bassa', '12' => 'Grand Cape Mount', '13' => 'Maryland', '14' => 'Montserrado', '17' => 'Margibi', '18' => 'River Cess', '19' => 'Grand Gedeh', '20' => 'Lofa', '21' => 'Gbarpolu', '22' => 'River Gee'], 'LS' => ['10' => 'Berea', '11' => 'Butha-Buthe', '12' => 'Leribe', '13' => 'Mafeteng', '14' => 'Maseru', '15' => 'Mohale\'s Hoek', '16' => 'Mokhotlong', '17' => 'Qacha\'s Nek', '18' => 'Quthing', '19' => 'Thaba-Tseka'], 'LT' => ['56' => 'Alytaus apskritis', '57' => 'Kauno apskritis', '58' => 'Klaipedos apskritis', '59' => 'Marijampoles apskritis', '60' => 'Panevezio apskritis', '61' => 'Siauliu apskritis', '62' => 'Taurages apskritis', '63' => 'Telsiu apskritis', '64' => 'Utenos apskritis', '65' => 'Vilniaus apskritis'], 'LU' => ['01' => 'Diekirch', '02' => 'Grevenmacher', '03' => 'Luxembourg'], 'LV' => ['01' => 'Aizkraukles novads', '02' => 'Aluksnes novads', '03' => 'Balvu novads', '04' => 'Bauskas novads', '05' => 'Cesu novads', '06' => 'Daugavpils', '07' => 'Daugavpils novads', '08' => 'Dobeles novads', '09' => 'Gulbenes novads', '10' => 'Jekabpils novads', '11' => 'Jelgava', '12' => 'Jelgavas novads', '13' => 'Jurmala', '14' => 'Kraslavas novads', '15' => 'Kuldigas novads', '16' => 'Liepaja', '17' => 'Liepaja', '18' => 'Limbazu novads', '19' => 'Ludzas novads', '20' => 'Madonas novads', '21' => 'Ogres novads', '22' => 'Preilu novads', '23' => 'Rezeknes novads', '24' => 'Rezeknes novads', '25' => 'Riga', '26' => 'Riga', '27' => 'Saldus novads', '28' => 'Talsu novads', '29' => 'Tukuma novads', '30' => 'Valkas novads', '31' => 'Valmiera', '32' => 'Ventspils', '33' => 'Ventspils novads'], 'LY' => ['05' => 'Al Jufrah', '08' => 'Al Kufrah', '30' => 'Murzuq', '34' => 'Sabha', '49' => 'Al Jabal al Akhdar', '51' => 'An Nuqat al Khams', '53' => 'Az Zawiyah', '54' => 'Banghazi', '55' => 'Darnah', '58' => 'Misratah', '60' => 'Surt', '61' => 'Tarabulus'], 'MA' => ['54' => 'L\'Oriental'], 'MC' => ['01' => 'La Condamine', '02' => 'Monaco-Ville', '03' => 'Monte-Carlo'], 'MD' => ['51' => 'Gagauzia, Unitatea teritoriala autonoma', '57' => 'Chisinau', '58' => 'Stinga Nistrului, unitatea teritoriala din', '59' => 'Anenii Noi', '60' => 'Balti', '61' => 'Basarabeasca', '62' => 'Bender', '63' => 'Briceni', '64' => 'Cahul', '65' => 'Cantemir', '66' => 'Calarasi', '67' => 'Causeni', '68' => 'Cimislia', '69' => 'Criuleni', '70' => 'Donduseni', '71' => 'Drochia', '72' => 'Dubasari', '73' => 'Edinet', '74' => 'Falesti', '75' => 'Floresti', '76' => 'Glodeni', '77' => 'Hincesti', '78' => 'Ialoveni', '79' => 'Leova', '80' => 'Nisporeni', '81' => 'Ocnita', '82' => 'Orhei', '83' => 'Rezina', '84' => 'Riscani', '85' => 'Singerei', '86' => 'Soldanesti', '87' => 'Soroca', '88' => 'Stefan Voda', '89' => 'Straseni', '90' => 'Taraclia', '91' => 'Telenesti', '92' => 'Ungheni'], 'MG' => ['01' => 'Antsiranana', '02' => 'Fianarantsoa', '03' => 'Mahajanga', '04' => 'Toamasina', '05' => 'Antananarivo', '06' => 'Toliara'], 'MK' => ['01' => 'Aracinovo', '02' => 'Novaci', '03' => 'Debarca', '04' => 'Berovo', '05' => 'Bitola', '06' => 'Bitola', '08' => 'Bogdanci', '09' => 'Caska', '10' => 'Bogovinje', '11' => 'Bosilovo', '12' => 'Brvenica', '13' => 'Skopje', '14' => 'Bitola', '15' => 'Caska', '16' => 'Gostivar', '17' => 'Skopje', '18' => 'Centar Zupa', '20' => 'Cucer Sandevo', '21' => 'Debar', '22' => 'Delcevo', '23' => 'Struga', '24' => 'Demir Hisar', '25' => 'Demir Kapija', '26' => 'Mogila', '27' => 'Gostivar', '28' => 'Dolneni', '29' => 'Skopje', '30' => 'Kicevo', '31' => 'Tetovo', '32' => 'Skopje', '33' => 'Gevgelija', '34' => 'Gostivar', '35' => 'Gradsko', '36' => 'Ilinden', '38' => 'Jegunovce', '39' => 'Bogovinje', '40' => 'Karbinci', '42' => 'Kavadarci', '43' => 'Kicevo', '44' => 'Skopje', '46' => 'Kocani', '47' => 'Konce', '49' => 'Kavadarci', '50' => 'Ohrid', '51' => 'Kratovo', '52' => 'Kriva Palanka', '53' => 'Krivogastani', '54' => 'Krusevo', '55' => 'Strumica', '56' => 'Bitola', '57' => 'Kumanovo', '58' => 'Struga', '59' => 'Lipkovo', '60' => 'Lozovo', '61' => 'Struga', '62' => 'Makedonska Kamenica', '63' => 'Makedonski Brod', '65' => 'Debarca', '66' => 'Gevgelija', '67' => 'Mogila', '69' => 'Negotino', '71' => 'Novaci', '72' => 'Novo Selo', '73' => 'Cesinovo-Oblesevo', '74' => 'Ohrid', '75' => 'Kumanovo', '76' => 'Kocani', '77' => 'Kicevo', '78' => 'Pehcevo', '79' => 'Petrovec', '80' => 'Plasnica', '81' => 'Radovis', '82' => 'Prilep', '83' => 'Probistip', '84' => 'Radovis', '85' => 'Rankovce', '86' => 'Resen', '87' => 'Rosoman', '88' => 'Mavrovo i Rostusa', '89' => 'Makedonski Brod', '91' => 'Tetovo', '92' => 'Sopiste', '93' => 'Demir Hisar', '94' => 'Gostivar', '95' => 'Novaci', '96' => 'Dojran', '97' => 'Staro Nagoricane', '98' => 'Stip', '99' => 'Struga', 'A1' => 'Strumica', 'A2' => 'Studenicani', 'A4' => 'Sveti Nikole', 'A5' => 'Tearce', 'A6' => 'Tetovo', 'A7' => 'Prilep', 'A8' => 'Valandovo', 'A9' => 'Vasilevo', 'B1' => 'Veles', 'B2' => 'Struga', 'B3' => 'Vevcani', 'B4' => 'Vinica', 'B5' => 'Prilep', 'B6' => 'Kicevo', 'B7' => 'Vrapciste', 'B8' => 'Jegunovce', 'B9' => 'Gostivar', 'C1' => 'Kicevo', 'C2' => 'Zelenikovo', 'C3' => 'Zelino', 'C4' => 'Dolneni', 'C5' => 'Probistip', 'C6' => 'Zrnovci'], 'ML' => ['01' => 'Bamako', '03' => 'Kayes', '04' => 'Mopti', '05' => 'Segou', '06' => 'Sikasso', '07' => 'Koulikoro', '08' => 'Tombouctou', '09' => 'Gao', '10' => 'Kidal'], 'MM' => ['01' => 'Rakhine', '02' => 'Chin', '03' => 'Ayeyarwady', '04' => 'Kachin', '05' => 'Kayin', '06' => 'Kayah', '07' => 'Magway', '08' => 'Mandalay', '09' => 'Bago', '10' => 'Sagaing', '11' => 'Shan', '12' => 'Tanintharyi', '13' => 'Mon', '14' => 'Yangon', '17' => 'Yangon'], 'MN' => ['01' => 'Arhangay', '02' => 'Bayanhongor', '03' => 'Bayan-Olgiy', '05' => 'Darhan uul', '06' => 'Dornod', '07' => 'Dornogovi', '08' => 'Dundgovi', '09' => 'Dzavhan', '10' => 'Govi-Altay', '11' => 'Hentiy', '12' => 'Hovd', '13' => 'Hovsgol', '14' => 'Omnogovi', '15' => 'Ovorhangay', '16' => 'Selenge', '17' => 'Suhbaatar', '18' => 'Tov', '19' => 'Uvs', '20' => 'Ulaanbaatar', '21' => 'Bulgan', '22' => 'Orhon', '23' => 'Darhan uul', '24' => 'Govi-Sumber', '25' => 'Orhon'], 'MO' => ['02' => 'Macao'], 'MR' => ['01' => 'Hodh ech Chargui', '02' => 'Hodh el Gharbi', '03' => 'Assaba', '04' => 'Gorgol', '05' => 'Brakna', '06' => 'Trarza', '07' => 'Adrar', '08' => 'Dakhlet Nouadhibou', '09' => 'Tagant', '10' => 'Guidimaka', '11' => 'Tiris Zemmour', '12' => 'Inchiri'], 'MS' => ['01' => 'Saint Anthony', '03' => 'Saint Peter'], 'MU' => ['12' => 'Black River', '13' => 'Flacq', '14' => 'Grand Port', '15' => 'Moka', '16' => 'Pamplemousses', '17' => 'Plaines Wilhems', '18' => 'Port Louis', '19' => 'Riviere du Rempart', '20' => 'Savanne', '21' => 'Agalega Islands', '23' => 'Rodrigues Islands'], 'MV' => ['01' => 'Seenu', '05' => 'Laamu', '30' => 'Alifu Alifu', '31' => 'Baa', '32' => 'Dhaalu', '35' => 'Gaafu Dhaalu', '36' => 'Haa Alifu', '37' => 'Haa Dhaalu', '38' => 'Kaafu', '40' => 'Maale', '41' => 'Meemu', '42' => 'Gnaviyani', '43' => 'Noonu', '44' => 'Raa', '45' => 'Shaviyani', '46' => 'Thaa', '47' => 'Vaavu'], 'MW' => ['02' => 'Chikwawa', '03' => 'Chiradzulu', '04' => 'Chitipa', '05' => 'Thyolo', '06' => 'Dedza', '07' => 'Dowa', '08' => 'Karonga', '09' => 'Kasungu', '11' => 'Lilongwe', '12' => 'Mangochi', '13' => 'Mchinji', '15' => 'Mzimba', '16' => 'Ntcheu', '17' => 'Nkhata Bay', '18' => 'Nkhotakota', '19' => 'Nsanje', '20' => 'Ntchisi', '21' => 'Rumphi', '22' => 'Salima', '23' => 'Zomba', '24' => 'Blantyre', '25' => 'Mwanza', '26' => 'Balaka', '27' => 'Likoma', '28' => 'Machinga', '29' => 'Mulanje', '30' => 'Phalombe'], 'MX' => ['01' => 'Aguascalientes', '02' => 'Baja California', '03' => 'Baja California Sur', '04' => 'Campeche', '05' => 'Chiapas', '06' => 'Chihuahua', '07' => 'Coahuila de Zaragoza', '08' => 'Colima', '09' => 'Ciudad de Mexico', '10' => 'Durango', '11' => 'Guanajuato', '12' => 'Guerrero', '13' => 'Hidalgo', '14' => 'Jalisco', '15' => 'Mexico', '16' => 'Michoacan de Ocampo', '17' => 'Morelos', '18' => 'Nayarit', '19' => 'Nuevo Leon', '20' => 'Oaxaca', '21' => 'Puebla', '22' => 'Queretaro', '23' => 'Quintana Roo', '24' => 'San Luis Potosi', '25' => 'Sinaloa', '26' => 'Sonora', '27' => 'Tabasco', '28' => 'Tamaulipas', '29' => 'Tlaxcala', '30' => 'Veracruz de Ignacio de la Llave', '31' => 'Yucatan', '32' => 'Zacatecas'], 'MY' => ['01' => 'Johor', '02' => 'Kedah', '03' => 'Kelantan', '04' => 'Melaka', '05' => 'Negeri Sembilan', '06' => 'Pahang', '07' => 'Perak', '08' => 'Perlis', '09' => 'Pulau Pinang', '11' => 'Sarawak', '12' => 'Selangor', '13' => 'Terengganu', '14' => 'Wilayah Persekutuan Kuala Lumpur', '15' => 'Wilayah Persekutuan Labuan', '16' => 'Sabah', '17' => 'Wilayah Persekutuan Putrajaya'], 'MZ' => ['01' => 'Cabo Delgado', '02' => 'Gaza', '03' => 'Inhambane', '04' => 'Maputo', '05' => 'Sofala', '06' => 'Nampula', '07' => 'Niassa', '08' => 'Tete', '09' => 'Zambezia', '10' => 'Manica', '11' => 'Maputo'], 'NA' => ['01' => 'Karas', '04' => 'Omaheke', '05' => 'Otjozondjupa', '06' => 'Kunene', '07' => 'Erongo', '08' => 'Karas', '09' => 'Karas', '10' => 'Hardap', '11' => 'Otjozondjupa', '12' => 'Erongo', '13' => 'Otjozondjupa', '14' => 'Kunene', '16' => 'Hardap', '17' => 'Erongo', '18' => 'Oshikoto', '20' => 'Karas', '21' => 'Khomas', '26' => 'Hardap', '28' => 'Zambezi', '29' => 'Erongo', '30' => 'Hardap', '31' => 'Karas', '32' => 'Kunene', '33' => 'Ohangwena', '34' => 'Kavango East', '35' => 'Omaheke', '36' => 'Omusati', '37' => 'Oshana', '38' => 'Oshikoto', '39' => 'Otjozondjupa'], 'NE' => ['01' => 'Agadez', '02' => 'Diffa', '03' => 'Dosso', '04' => 'Maradi', '05' => 'Niamey', '06' => 'Tahoua', '07' => 'Zinder', '08' => 'Niamey'], 'NG' => ['05' => 'Lagos', '11' => 'Abuja Federal Capital Territory', '16' => 'Ogun', '21' => 'Akwa Ibom', '22' => 'Cross River', '23' => 'Kaduna', '24' => 'Katsina', '25' => 'Anambra', '26' => 'Benue', '27' => 'Borno', '28' => 'Imo', '29' => 'Kano', '30' => 'Kwara', '31' => 'Niger', '32' => 'Oyo', '35' => 'Adamawa', '36' => 'Delta', '37' => 'Edo', '39' => 'Jigawa', '40' => 'Kebbi', '41' => 'Kogi', '42' => 'Osun', '43' => 'Taraba', '44' => 'Yobe', '45' => 'Abia', '46' => 'Bauchi', '47' => 'Enugu', '48' => 'Ondo', '49' => 'Plateau', '50' => 'Rivers', '51' => 'Sokoto', '52' => 'Bayelsa', '53' => 'Ebonyi', '54' => 'Ekiti', '55' => 'Gombe', '56' => 'Nasarawa', '57' => 'Zamfara'], 'NI' => ['01' => 'Boaco', '02' => 'Carazo', '03' => 'Chinandega', '04' => 'Chontales', '05' => 'Esteli', '06' => 'Granada', '07' => 'Jinotega', '08' => 'Leon', '09' => 'Madriz', '10' => 'Managua', '11' => 'Masaya', '12' => 'Matagalpa', '13' => 'Nueva Segovia', '14' => 'Rio San Juan', '15' => 'Rivas', '16' => 'Costa Caribe Sur', '17' => 'Costa Caribe Norte', '18' => 'Costa Caribe Sur'], 'NL' => ['01' => 'Drenthe', '02' => 'Fryslan', '03' => 'Gelderland', '04' => 'Groningen', '05' => 'Limburg', '06' => 'Noord-Brabant', '07' => 'Noord-Holland', '09' => 'Utrecht', '10' => 'Zeeland', '11' => 'Zuid-Holland', '15' => 'Overijssel', '16' => 'Flevoland'], 'NO' => ['01' => 'Akershus', '02' => 'Aust-Agder', '04' => 'Buskerud', '05' => 'Finnmark', '06' => 'Hedmark', '07' => 'Hordaland', '08' => 'More og Romsdal', '09' => 'Nordland', '10' => 'Nord-Trondelag', '11' => 'Oppland', '12' => 'Oslo', '13' => 'Ostfold', '14' => 'Rogaland', '15' => 'Sogn og Fjordane', '16' => 'Sor-Trondelag', '17' => 'Telemark', '18' => 'Troms', '19' => 'Vest-Agder', '20' => 'Vestfold'], 'NP' => ['01' => 'Bagmati', '02' => 'Bheri', '03' => 'Dhawalagiri', '04' => 'Gandaki', '05' => 'Janakpur', '06' => 'Karnali', '07' => 'Kosi', '08' => 'Lumbini', '09' => 'Mahakali', '10' => 'Mechi', '11' => 'Narayani', '12' => 'Rapti', '13' => 'Sagarmatha', '14' => 'Seti'], 'NR' => ['01' => 'Aiwo', '02' => 'Anabar', '03' => 'Anetan', '04' => 'Anibare', '05' => 'Baitsi', '07' => 'Buada', '09' => 'Ewa', '10' => 'Ijuw', '13' => 'Uaboe', '14' => 'Yaren'], 'NZ' => ['10' => 'Chatham Islands Territory', 'E7' => 'Auckland', 'E8' => 'Bay of Plenty', 'E9' => 'Canterbury', 'F1' => 'Gisborne', 'F2' => 'Hawke\'s Bay', 'F3' => 'Manawatu-Wanganui', 'F4' => 'Marlborough', 'F5' => 'Nelson', 'F6' => 'Northland', 'F7' => 'Otago', 'F8' => 'Southland', 'F9' => 'Taranaki', 'G1' => 'Waikato', 'G2' => 'Wellington', 'G3' => 'West Coast'], 'OM' => ['01' => 'Ad Dakhiliyah', '02' => 'Janub al Batinah', '03' => 'Al Wusta', '04' => 'Janub ash Sharqiyah', '05' => 'Az Zahirah', '06' => 'Masqat', '07' => 'Musandam', '08' => 'Zufar'], 'PA' => ['01' => 'Bocas del Toro', '02' => 'Chiriqui', '03' => 'Cocle', '04' => 'Colon', '05' => 'Darien', '06' => 'Herrera', '07' => 'Los Santos', '08' => 'Panama', '09' => 'Panama', '10' => 'Veraguas'], 'PE' => ['01' => 'Amazonas', '02' => 'Ancash', '03' => 'Apurimac', '04' => 'Arequipa', '05' => 'Ayacucho', '06' => 'Cajamarca', '07' => 'El Callao', '08' => 'Cusco', '09' => 'Huancavelica', '10' => 'Huanuco', '11' => 'Ica', '12' => 'Junin', '13' => 'La Libertad', '14' => 'Lambayeque', '15' => 'Lima', '16' => 'Loreto', '17' => 'Madre de Dios', '18' => 'Moquegua', '19' => 'Pasco', '20' => 'Piura', '21' => 'Puno', '22' => 'San Martin', '23' => 'Tacna', '24' => 'Tumbes', '25' => 'Ucayali'], 'PG' => ['01' => 'Central', '02' => 'Gulf', '03' => 'Milne Bay', '04' => 'Northern', '05' => 'Southern Highlands', '06' => 'Western', '07' => 'Bougainville', '08' => 'Chimbu', '09' => 'Eastern Highlands', '10' => 'East New Britain', '11' => 'East Sepik', '12' => 'Madang', '13' => 'Manus', '14' => 'Morobe', '15' => 'New Ireland', '16' => 'Western Highlands', '17' => 'West New Britain', '18' => 'West Sepik', '19' => 'Enga', '20' => 'National Capital District (Port Moresby)'], 'PH' => ['01' => 'Abra', '02' => 'Agusan del Norte', '03' => 'Agusan del Sur', '04' => 'Aklan', '05' => 'Albay', '06' => 'Antique', '07' => 'Bataan', '08' => 'Batanes', '09' => 'Batangas', '10' => 'Benguet', '11' => 'Bohol', '12' => 'Bukidnon', '13' => 'Bulacan', '14' => 'Cagayan', '15' => 'Camarines Norte', '16' => 'Camarines Sur', '17' => 'Camiguin', '18' => 'Capiz', '19' => 'Catanduanes', '20' => 'Cavite', '21' => 'Cebu', '22' => 'Basilan', '23' => 'Eastern Samar', '25' => 'Davao del Sur', '26' => 'Davao Oriental', '27' => 'Ifugao', '28' => 'Ilocos Norte', '29' => 'Ilocos Sur', '30' => 'Iloilo', '31' => 'Isabela', '33' => 'Laguna', '34' => 'Lanao del Norte', '35' => 'Lanao del Sur', '36' => 'La Union', '37' => 'Leyte', '38' => 'Marinduque', '39' => 'Masbate', '40' => 'Mindoro Occidental', '41' => 'Mindoro Oriental', '42' => 'Misamis Occidental', '43' => 'Misamis Oriental', '44' => 'Mountain Province', '45' => 'Negros Occidental', '46' => 'Negros Oriental', '47' => 'Nueva Ecija', '48' => 'Nueva Vizcaya', '49' => 'Palawan', '50' => 'Pampanga', '51' => 'Pangasinan', '53' => 'Rizal', '54' => 'Romblon', '55' => 'Samar', '56' => 'Maguindanao', '58' => 'Sorsogon', '59' => 'Southern Leyte', '60' => 'Sulu', '61' => 'Surigao del Norte', '62' => 'Surigao del Sur', '63' => 'Tarlac', '64' => 'Zambales', '65' => 'Zamboanga del Norte', '66' => 'Zamboanga del Sur', '67' => 'Northern Samar', '68' => 'Quirino', '69' => 'Siquijor', '70' => 'South Cotabato', '71' => 'Sultan Kudarat', '72' => 'Tawi-Tawi', 'A1' => 'Pampanga', 'A2' => 'Negros Occidental', 'A3' => 'Negros Occidental', 'A4' => 'Benguet', 'A5' => 'Negros Oriental', 'A6' => 'Basilan', 'A8' => 'Agusan del Norte', 'A9' => 'Nueva Ecija', 'B2' => 'Misamis Occidental', 'B3' => 'Samar', 'B5' => 'Negros Oriental', 'B6' => 'Cavite', 'B7' => 'Cebu', 'B8' => 'Cotabato', 'B9' => 'Pangasinan', 'C2' => 'Zamboanga del Norte', 'C3' => 'Davao del Sur', 'C4' => 'Zamboanga del Norte', 'C5' => 'Negros Oriental', 'C6' => 'South Cotabato', 'C7' => 'Misamis Oriental', 'C8' => 'Lanao del Norte', 'C9' => 'Iloilo', 'D1' => 'Camarines Sur', 'D2' => 'Negros Occidental', 'D3' => 'Ilocos Norte', 'D4' => 'Cebu', 'D5' => 'Albay', 'D6' => 'Batangas', 'D7' => 'Quezon', 'D8' => 'Cebu', 'D9' => 'National Capital Region', 'E1' => 'Lanao del Sur', 'E2' => 'Camarines Sur', 'E3' => 'Zambales', 'E4' => 'Leyte', 'E5' => 'Misamis Occidental', 'E6' => 'Misamis Occidental', 'E7' => 'Zamboanga del Sur', 'E8' => 'Nueva Ecija', 'F1' => 'Palawan', 'F3' => 'Capiz', 'F7' => 'Laguna', 'F8' => 'Negros Occidental', 'F9' => 'Surigao del Norte', 'G1' => 'Leyte', 'G2' => 'Cavite', 'G3' => 'Bohol', 'G4' => 'Misamis Occidental', 'G5' => 'Cebu', 'G6' => 'Cavite', 'G7' => 'Zamboanga del Sur', 'G8' => 'Aurora', 'H2' => 'Quezon', 'H3' => 'Negros Occidental', 'I6' => 'Compostela Valley', 'I7' => 'Davao del Norte', 'J7' => 'Kalinga', 'K6' => 'Bukidnon', 'M5' => 'Bulacan', 'M8' => 'Cagayan', 'M9' => 'Sarangani', 'N1' => 'Negros Occidental', 'N3' => 'Surigao del Norte', 'P1' => 'Zambales'], 'PK' => ['01' => 'Federally Administered Tribal Areas', '02' => 'Balochistan', '03' => 'Khyber Pakhtunkhwa', '04' => 'Punjab', '05' => 'Sindh', '06' => 'Azad Jammu and Kashmir', '07' => 'Gilgit-Baltistan', '08' => 'Islamabad'], 'PL' => ['72' => 'Dolnoslaskie', '73' => 'Kujawsko-pomorskie', '74' => 'Lodzkie', '75' => 'Lubelskie', '76' => 'Lubuskie', '77' => 'Malopolskie', '78' => 'Mazowieckie', '79' => 'Opolskie', '80' => 'Podkarpackie', '81' => 'Podlaskie', '82' => 'Pomorskie', '83' => 'Slaskie', '84' => 'Swietokrzyskie', '85' => 'Warminsko-mazurskie', '86' => 'Wielkopolskie', '87' => 'Zachodniopomorskie'], 'PS' => ['GZ' => 'Gaza', 'WE' => 'Tulkarm'], 'PT' => ['02' => 'Aveiro', '03' => 'Beja', '04' => 'Braga', '05' => 'Braganca', '06' => 'Castelo Branco', '07' => 'Coimbra', '08' => 'Evora', '09' => 'Faro', '10' => 'Regiao Autonoma da Madeira', '11' => 'Guarda', '13' => 'Leiria', '14' => 'Lisboa', '16' => 'Portalegre', '17' => 'Porto', '18' => 'Santarem', '19' => 'Setubal', '20' => 'Viana do Castelo', '21' => 'Vila Real', '22' => 'Viseu', '23' => 'Regiao Autonoma dos Acores'], 'PY' => ['01' => 'Alto Parana', '02' => 'Amambay', '03' => 'Boqueron', '04' => 'Caaguazu', '05' => 'Caazapa', '06' => 'Central', '07' => 'Concepcion', '08' => 'Cordillera', '10' => 'Guaira', '11' => 'Itapua', '12' => 'Misiones', '13' => 'Neembucu', '15' => 'Paraguari', '16' => 'Presidente Hayes', '17' => 'San Pedro', '19' => 'Canindeyu', '21' => 'Asuncion', '23' => 'Alto Paraguay'], 'QA' => ['01' => 'Ad Dawhah', '02' => 'Al Khawr wa adh Dhakhirah', '04' => 'Al Khawr wa adh Dhakhirah', '05' => 'Al Wakrah', '06' => 'Ar Rayyan', '08' => 'Ash Shamal', '09' => 'Umm Salal', '10' => 'Al Wakrah', '11' => 'Ar Rayyan', '12' => 'Al Wakrah'], 'RO' => ['01' => 'Alba', '02' => 'Arad', '03' => 'Arges', '04' => 'Bacau', '05' => 'Bihor', '06' => 'Bistrita-Nasaud', '07' => 'Botosani', '08' => 'Braila', '09' => 'Brasov', '10' => 'Bucuresti', '11' => 'Buzau', '12' => 'Caras-Severin', '13' => 'Cluj', '14' => 'Constanta', '15' => 'Covasna', '16' => 'Dambovita', '17' => 'Dolj', '18' => 'Galati', '19' => 'Gorj', '20' => 'Harghita', '21' => 'Hunedoara', '22' => 'Ialomita', '23' => 'Iasi', '25' => 'Maramures', '26' => 'Mehedinti', '27' => 'Mures', '28' => 'Neamt', '29' => 'Olt', '30' => 'Prahova', '31' => 'Salaj', '32' => 'Satu Mare', '33' => 'Sibiu', '34' => 'Suceava', '35' => 'Teleorman', '36' => 'Timis', '37' => 'Tulcea', '38' => 'Vaslui', '39' => 'Valcea', '40' => 'Vrancea', '41' => 'Calarasi', '42' => 'Giurgiu', '43' => 'Ilfov'], 'RS' => ['01' => 'Kosovsko-Mitrovacki okrug', '02' => 'Sremski okrug'], 'RU' => ['01' => 'Adygeya, Respublika', '03' => 'Altay, Respublika', '04' => 'Altayskiy kray', '05' => 'Amurskaya oblast\'', '06' => 'Arkhangel\'skaya oblast\'', '07' => 'Astrakhanskaya oblast\'', '08' => 'Bashkortostan, Respublika', '09' => 'Belgorodskaya oblast\'', '10' => 'Bryanskaya oblast\'', '11' => 'Buryatiya, Respublika', '12' => 'Chechenskaya Respublika', '13' => 'Chelyabinskaya oblast\'', '15' => 'Chukotskiy avtonomnyy okrug', '16' => 'Chuvashskaya Respublika', '17' => 'Dagestan, Respublika', '19' => 'Ingushetiya, Respublika', '20' => 'Irkutskaya oblast\'', '21' => 'Ivanovskaya oblast\'', '22' => 'Kabardino-Balkarskaya Respublika', '23' => 'Kaliningradskaya oblast\'', '24' => 'Kalmykiya, Respublika', '25' => 'Kaluzhskaya oblast\'', '27' => 'Karachayevo-Cherkesskaya Respublika', '28' => 'Kareliya, Respublika', '29' => 'Kemerovskaya oblast\'', '30' => 'Khabarovskiy kray', '31' => 'Khakasiya, Respublika', '32' => 'Khanty-Mansiyskiy avtonomnyy okrug', '33' => 'Kirovskaya oblast\'', '34' => 'Komi, Respublika', '37' => 'Kostromskaya oblast\'', '38' => 'Krasnodarskiy kray', '40' => 'Kurganskaya oblast\'', '41' => 'Kurskaya oblast\'', '42' => 'Leningradskaya oblast\'', '43' => 'Lipetskaya oblast\'', '44' => 'Magadanskaya oblast\'', '45' => 'Mariy El, Respublika', '46' => 'Mordoviya, Respublika', '47' => 'Moskovskaya oblast\'', '48' => 'Moskva', '49' => 'Murmanskaya oblast\'', '50' => 'Nenetskiy avtonomnyy okrug', '51' => 'Nizhegorodskaya oblast\'', '52' => 'Novgorodskaya oblast\'', '53' => 'Novosibirskaya oblast\'', '54' => 'Omskaya oblast\'', '55' => 'Orenburgskaya oblast\'', '56' => 'Orlovskaya oblast\'', '57' => 'Penzenskaya oblast\'', '59' => 'Primorskiy kray', '60' => 'Pskovskaya oblast\'', '61' => 'Rostovskaya oblast\'', '62' => 'Ryazanskaya oblast\'', '63' => 'Saha, Respublika', '64' => 'Sakhalinskaya oblast\'', '65' => 'Samarskaya oblast\'', '66' => 'Sankt-Peterburg', '67' => 'Saratovskaya oblast\'', '68' => 'Severnaya Osetiya, Respublika', '69' => 'Smolenskaya oblast\'', '70' => 'Stavropol\'skiy kray', '71' => 'Sverdlovskaya oblast\'', '72' => 'Tambovskaya oblast\'', '73' => 'Tatarstan, Respublika', '75' => 'Tomskaya oblast\'', '76' => 'Tul\'skaya oblast\'', '77' => 'Tverskaya oblast\'', '78' => 'Tyumenskaya oblast\'', '79' => 'Tyva, Respublika', '80' => 'Udmurtskaya Respublika', '81' => 'Ul\'yanovskaya oblast\'', '83' => 'Vladimirskaya oblast\'', '84' => 'Volgogradskaya oblast\'', '85' => 'Vologodskaya oblast\'', '86' => 'Voronezhskaya oblast\'', '87' => 'Yamalo-Nenetskiy avtonomnyy okrug', '88' => 'Yaroslavskaya oblast\'', '89' => 'Yevreyskaya avtonomnaya oblast\'', '90' => 'Permskiy kray', '91' => 'Krasnoyarskiy kray', '92' => 'Kamchatskiy kray', '93' => 'Zabaykal\'skiy kray'], 'RW' => ['01' => 'Sud', '06' => 'Sud', '07' => 'Est', '09' => 'Ville de Kigali', '11' => 'Est', '12' => 'Ville de Kigali', '13' => 'Nord', '14' => 'Ouest', '15' => 'Sud'], 'SA' => ['02' => 'Al Bahah', '05' => 'Al Madinah al Munawwarah', '06' => 'Ash Sharqiyah', '08' => 'Al Qasim', '10' => 'Ar Riyad', '11' => '\'Asir', '13' => 'Ha\'il', '14' => 'Makkah al Mukarramah', '15' => 'Al Hudud ash Shamaliyah', '16' => 'Najran', '17' => 'Jazan', '19' => 'Tabuk', '20' => 'Al Jawf'], 'SB' => ['03' => 'Malaita', '06' => 'Guadalcanal', '07' => 'Isabel', '08' => 'Makira-Ulawa', '09' => 'Temotu', '10' => 'Central', '11' => 'Western', '12' => 'Choiseul', '13' => 'Rennell and Bellona'], 'SC' => ['01' => 'Anse aux Pins', '02' => 'Anse Boileau', '05' => 'Anse Royale', '06' => 'Baie Lazare', '08' => 'Beau Vallon', '10' => 'Bel Ombre', '11' => 'Cascade', '13' => 'Grand Anse Mahe', '14' => 'Grand Anse Mahe', '15' => 'La Digue', '16' => 'English River', '20' => 'Pointe Larue', '21' => 'Port Glaud', '23' => 'Takamaka'], 'SD' => ['29' => 'Khartoum', '30' => 'Northern', '33' => 'North Darfur', '34' => 'North Kordofan'], 'SE' => ['02' => 'Blekinge lan', '03' => 'Gavleborgs lan', '05' => 'Gotlands lan', '06' => 'Hallands lan', '07' => 'Jamtlands lan', '08' => 'Jonkopings lan', '09' => 'Kalmar lan', '10' => 'Dalarnas lan', '12' => 'Kronobergs lan', '14' => 'Norrbottens lan', '15' => 'Orebro lan', '16' => 'Ostergotlands lan', '18' => 'Sodermanlands lan', '21' => 'Uppsala lan', '22' => 'Varmlands lan', '23' => 'Vasterbottens lan', '24' => 'Vasternorrlands lan', '25' => 'Vastmanlands lan', '26' => 'Stockholms lan', '27' => 'Skane lan', '28' => 'Vastra Gotalands lan'], 'SH' => ['01' => 'Ascension', '02' => 'Saint Helena', '03' => 'Tristan da Cunha'], 'SI' => ['01' => 'Ajdovscina', '02' => 'Beltinci', '03' => 'Bled', '04' => 'Bohinj', '05' => 'Borovnica', '06' => 'Bovec', '07' => 'Brda', '08' => 'Brezice', '09' => 'Brezovica', '11' => 'Celje', '12' => 'Cerklje na Gorenjskem', '13' => 'Cerknica', '14' => 'Cerkno', '15' => 'Crensovci', '17' => 'Crnomelj', '19' => 'Divaca', '20' => 'Dobrepolje', '24' => 'Dornava', '25' => 'Dravograd', '26' => 'Duplek', '29' => 'Gornja Radgona', '31' => 'Gornji Petrovci', '32' => 'Grosuplje', '34' => 'Hrastnik', '36' => 'Idrija', '37' => 'Ig', '38' => 'Ilirska Bistrica', '39' => 'Ivancna Gorica', '40' => 'Izola', '42' => 'Jursinci', '44' => 'Kanal', '45' => 'Kidricevo', '46' => 'Kobarid', '47' => 'Kobilje', '49' => 'Komen', '50' => 'Koper', '52' => 'Kranj', '53' => 'Kranjska Gora', '54' => 'Krsko', '55' => 'Kungota', '57' => 'Lasko', '61' => 'Ljubljana', '64' => 'Logatec', '66' => 'Loski Potok', '68' => 'Lukovica', '71' => 'Medvode', '72' => 'Menges', '73' => 'Metlika', '74' => 'Mezica', '76' => 'Mislinja', '77' => 'Moravce', '79' => 'Mozirje', '80' => 'Murska Sobota', '81' => 'Muta', '82' => 'Naklo', '83' => 'Nazarje', '84' => 'Nova Gorica', '86' => 'Odranci', '87' => 'Ormoz', '91' => 'Pivka', '92' => 'Podcetrtek', '94' => 'Postojna', '97' => 'Puconci', '98' => 'Race-Fram', '99' => 'Radece', 'A1' => 'Radenci', 'A2' => 'Radlje ob Dravi', 'A3' => 'Radovljica', 'A6' => 'Rogasovci', 'A7' => 'Rogaska Slatina', 'B1' => 'Semic', 'B2' => 'Sencur', 'B3' => 'Sentilj', 'B4' => 'Sentjernej', 'B6' => 'Sevnica', 'B7' => 'Sezana', 'B8' => 'Skocjan', 'B9' => 'Skofja Loka', 'C1' => 'Skofljica', 'C2' => 'Slovenj Gradec', 'C4' => 'Slovenske Konjice', 'C5' => 'Smarje pri Jelsah', 'C6' => 'Smartno ob Paki', 'C7' => 'Sostanj', 'C8' => 'Starse', 'C9' => 'Store', 'D1' => 'Sveti Jurij', 'D2' => 'Tolmin', 'D3' => 'Trbovlje', 'D4' => 'Trebnje', 'D5' => 'Trzic', 'D6' => 'Turnisce', 'D7' => 'Velenje', 'D8' => 'Velike Lasce', 'E1' => 'Vipava', 'E2' => 'Vitanje', 'E3' => 'Vodice', 'E5' => 'Vrhnika', 'E6' => 'Vuzenica', 'E7' => 'Zagorje ob Savi', 'E9' => 'Zavrc', 'F1' => 'Zelezniki', 'F2' => 'Ziri', 'F3' => 'Zrece', 'F4' => 'Benedikt', 'F5' => 'Bistrica ob Sotli', 'F6' => 'Bloke', 'F7' => 'Braslovce', 'F8' => 'Cankova', 'G1' => 'Destrnik', 'G2' => 'Dobje', 'G3' => 'Dobrna', 'G4' => 'Dobrova-Polhov Gradec', 'G5' => 'Dobrovnik', 'G7' => 'Domzale', 'G8' => 'Grad', 'G9' => 'Hajdina', 'H1' => 'Hoce-Slivnica', 'H2' => 'Hodos', 'H3' => 'Horjul', 'H4' => 'Jesenice', 'H6' => 'Kamnik', 'H7' => 'Kocevje', 'H8' => 'Komenda', 'H9' => 'Kostel', 'I2' => 'Kuzma', 'I3' => 'Lenart', 'I4' => 'Lendava', 'I5' => 'Litija', 'I6' => 'Ljutomer', 'I7' => 'Loska Dolina', 'I8' => 'Lovrenc na Pohorju', 'I9' => 'Luce', 'J1' => 'Majsperk', 'J2' => 'Maribor', 'J3' => 'Markovci', 'J4' => 'Miklavz na Dravskem Polju', 'J5' => 'Miren-Kostanjevica', 'J6' => 'Mirna Pec', 'J7' => 'Novo Mesto', 'J8' => 'Oplotnica', 'J9' => 'Piran', 'K1' => 'Podlehnik', 'K3' => 'Polzela', 'K4' => 'Prebold', 'K5' => 'Preddvor', 'K6' => 'Prevalje', 'K7' => 'Ptuj', 'K8' => 'Ravne na Koroskem', 'K9' => 'Razkrizje', 'L1' => 'Ribnica', 'L3' => 'Ruse', 'L4' => 'Salovci', 'L6' => 'Sempeter-Vrtojba', 'L7' => 'Sentjur', 'L8' => 'Slovenska Bistrica', 'L9' => 'Smartno pri Litiji', 'M1' => 'Sodrazica', 'M2' => 'Solcava', 'M4' => 'Sveti Andraz v Slovenskih Goricah', 'M5' => 'Tabor', 'M6' => 'Tisina', 'M7' => 'Trnovska Vas', 'M8' => 'Trzin', 'M9' => 'Velika Polana', 'N1' => 'Verzej', 'N2' => 'Videm', 'N3' => 'Vojnik', 'N4' => 'Vransko', 'N5' => 'Zalec', 'N6' => 'Zetale', 'N8' => 'Zuzemberk', 'N9' => 'Apace', 'O1' => 'Cirkulane'], 'SK' => ['01' => 'Banskobystricky kraj', '02' => 'Bratislavsky kraj', '03' => 'Kosicky kraj', '04' => 'Nitriansky kraj', '05' => 'Presovsky kraj', '06' => 'Trenciansky kraj', '07' => 'Trnavsky kraj', '08' => 'Zilinsky kraj'], 'SL' => ['01' => 'Eastern', '02' => 'Northern', '03' => 'Southern', '04' => 'Western Area'], 'SM' => ['01' => 'Acquaviva', '02' => 'Chiesanuova', '03' => 'Domagnano', '04' => 'Faetano', '05' => 'Fiorentino', '06' => 'Borgo Maggiore', '07' => 'San Marino', '08' => 'Montegiardino', '09' => 'Serravalle'], 'SN' => ['01' => 'Dakar', '03' => 'Diourbel', '05' => 'Tambacounda', '07' => 'Thies', '09' => 'Fatick', '10' => 'Kaolack', '11' => 'Kolda', '12' => 'Ziguinchor', '13' => 'Louga', '14' => 'Saint-Louis', '15' => 'Matam'], 'SO' => ['01' => 'Bakool', '02' => 'Banaadir', '03' => 'Bari', '04' => 'Bay', '05' => 'Galguduud', '06' => 'Gedo', '07' => 'Hiiraan', '08' => 'Jubbada Dhexe', '09' => 'Jubbada Hoose', '10' => 'Mudug', '11' => 'Nugaal', '12' => 'Sanaag', '13' => 'Shabeellaha Dhexe', '14' => 'Shabeellaha Hoose', '16' => 'Woqooyi Galbeed', '18' => 'Nugaal', '19' => 'Togdheer', '20' => 'Woqooyi Galbeed', '21' => 'Awdal', '22' => 'Sool'], 'SR' => ['10' => 'Brokopondo', '11' => 'Commewijne', '12' => 'Coronie', '13' => 'Marowijne', '14' => 'Nickerie', '15' => 'Para', '16' => 'Paramaribo', '17' => 'Saramacca', '18' => 'Sipaliwini', '19' => 'Wanica'], 'SS' => ['01' => 'Central Equatoria', '02' => 'Eastern Equatoria', '03' => 'Jonglei', '04' => 'Lakes', '05' => 'Northern Bahr el Ghazal', '06' => 'Unity', '07' => 'Upper Nile', '08' => 'Warrap', '09' => 'Western Bahr el Ghazal', '10' => 'Western Equatoria'], 'ST' => ['01' => 'Principe', '02' => 'Sao Tome'], 'SV' => ['01' => 'Ahuachapan', '02' => 'Cabanas', '03' => 'Chalatenango', '04' => 'Cuscatlan', '05' => 'La Libertad', '06' => 'La Paz', '07' => 'La Union', '08' => 'Morazan', '09' => 'San Miguel', '10' => 'San Salvador', '11' => 'Santa Ana', '12' => 'San Vicente', '13' => 'Sonsonate', '14' => 'Usulutan'], 'SY' => ['01' => 'Al Hasakah', '02' => 'Al Ladhiqiyah', '03' => 'Al Qunaytirah', '04' => 'Ar Raqqah', '05' => 'As Suwayda\'', '06' => 'Dar\'a', '07' => 'Dayr az Zawr', '08' => 'Rif Dimashq', '09' => 'Halab', '10' => 'Hamah', '11' => 'Hims', '12' => 'Idlib', '13' => 'Dimashq', '14' => 'Tartus'], 'SZ' => ['01' => 'Hhohho', '02' => 'Lubombo', '03' => 'Manzini', '04' => 'Shiselweni'], 'TD' => ['01' => 'Batha', '02' => 'Wadi Fira', '03' => 'Tibesti', '04' => 'Chari-Baguirmi', '05' => 'Guera', '06' => 'Kanem', '07' => 'Lac', '08' => 'Logone-Occidental', '09' => 'Logone-Oriental', '10' => 'Mayo-Kebbi-Ouest', '11' => 'Moyen-Chari', '12' => 'Ouaddai', '13' => 'Salamat', '14' => 'Tandjile'], 'TG' => ['22' => 'Centrale', '23' => 'Kara', '24' => 'Maritime', '25' => 'Plateaux', '26' => 'Savanes'], 'TH' => ['01' => 'Mae Hong Son', '02' => 'Chiang Mai', '03' => 'Chiang Rai', '04' => 'Nan', '05' => 'Lamphun', '06' => 'Lampang', '07' => 'Phrae', '08' => 'Tak', '09' => 'Sukhothai', '10' => 'Uttaradit', '11' => 'Kamphaeng Phet', '12' => 'Phitsanulok', '13' => 'Phichit', '14' => 'Phetchabun', '15' => 'Uthai Thani', '16' => 'Nakhon Sawan', '17' => 'Nong Khai', '18' => 'Loei', '20' => 'Sakon Nakhon', '21' => 'Nakhon Phanom', '22' => 'Khon Kaen', '23' => 'Kalasin', '24' => 'Maha Sarakham', '25' => 'Roi Et', '26' => 'Chaiyaphum', '27' => 'Nakhon Ratchasima', '28' => 'Buri Ram', '29' => 'Surin', '30' => 'Si Sa Ket', '31' => 'Narathiwat', '32' => 'Chai Nat', '33' => 'Sing Buri', '34' => 'Lop Buri', '35' => 'Ang Thong', '36' => 'Phra Nakhon Si Ayutthaya', '37' => 'Saraburi', '38' => 'Nonthaburi', '39' => 'Pathum Thani', '40' => 'Krung Thep Maha Nakhon', '41' => 'Phayao', '42' => 'Samut Prakan', '43' => 'Nakhon Nayok', '44' => 'Chachoengsao', '45' => 'Prachin Buri', '46' => 'Chon Buri', '47' => 'Rayong', '48' => 'Chanthaburi', '49' => 'Trat', '50' => 'Kanchanaburi', '51' => 'Suphan Buri', '52' => 'Ratchaburi', '53' => 'Nakhon Pathom', '54' => 'Samut Songkhram', '55' => 'Samut Sakhon', '56' => 'Phetchaburi', '57' => 'Prachuap Khiri Khan', '58' => 'Chumphon', '59' => 'Ranong', '60' => 'Surat Thani', '61' => 'Phangnga', '62' => 'Phuket', '63' => 'Krabi', '64' => 'Nakhon Si Thammarat', '65' => 'Trang', '66' => 'Phatthalung', '67' => 'Satun', '68' => 'Songkhla', '69' => 'Pattani', '70' => 'Yala', '71' => 'Ubon Ratchathani', '72' => 'Yasothon', '73' => 'Nakhon Phanom', '74' => 'Prachin Buri', '75' => 'Ubon Ratchathani', '76' => 'Udon Thani', '77' => 'Amnat Charoen', '78' => 'Mukdahan', '79' => 'Nong Bua Lam Phu', '80' => 'Sa Kaeo'], 'TJ' => ['01' => 'Kuhistoni Badakhshon', '02' => 'Khatlon', '03' => 'Sughd'], 'TM' => ['01' => 'Ahal', '02' => 'Balkan', '03' => 'Dasoguz', '04' => 'Lebap', '05' => 'Mary'], 'TN' => ['02' => 'Kasserine', '03' => 'Kairouan', '06' => 'Jendouba', '10' => 'Gafsa', '14' => 'Le Kef', '15' => 'Mahdia', '16' => 'Monastir', '17' => 'Beja', '18' => 'Bizerte', '19' => 'Nabeul', '22' => 'Siliana', '23' => 'Sousse', '27' => 'Ben Arous', '28' => 'Medenine', '29' => 'Gabes', '31' => 'Kebili', '32' => 'Sfax', '33' => 'Sidi Bouzid', '34' => 'Tataouine', '35' => 'Tozeur', '36' => 'Tunis', '37' => 'Zaghouan', '38' => 'L\'Ariana', '39' => 'La Manouba'], 'TO' => ['01' => 'Ha\'apai', '02' => 'Tongatapu', '03' => 'Vava\'u'], 'TR' => ['02' => 'Adiyaman', '03' => 'Afyonkarahisar', '04' => 'Agri', '05' => 'Amasya', '07' => 'Antalya', '08' => 'Artvin', '09' => 'Aydin', '10' => 'Balikesir', '11' => 'Bilecik', '12' => 'Bingol', '13' => 'Bitlis', '14' => 'Bolu', '15' => 'Burdur', '16' => 'Bursa', '17' => 'Canakkale', '19' => 'Corum', '20' => 'Denizli', '21' => 'Diyarbakir', '22' => 'Edirne', '23' => 'Elazig', '24' => 'Erzincan', '25' => 'Erzurum', '26' => 'Eskisehir', '28' => 'Giresun', '31' => 'Hatay', '32' => 'Mersin', '33' => 'Isparta', '34' => 'Istanbul', '35' => 'Izmir', '37' => 'Kastamonu', '38' => 'Kayseri', '39' => 'Kirklareli', '40' => 'Kirsehir', '41' => 'Kocaeli', '43' => 'Kutahya', '44' => 'Malatya', '45' => 'Manisa', '46' => 'Kahramanmaras', '48' => 'Mugla', '49' => 'Mus', '50' => 'Nevsehir', '52' => 'Ordu', '53' => 'Rize', '54' => 'Sakarya', '55' => 'Samsun', '57' => 'Sinop', '58' => 'Sivas', '59' => 'Tekirdag', '60' => 'Tokat', '61' => 'Trabzon', '62' => 'Tunceli', '63' => 'Sanliurfa', '64' => 'Usak', '65' => 'Van', '66' => 'Yozgat', '68' => 'Ankara', '69' => 'Gumushane', '70' => 'Hakkari', '71' => 'Konya', '72' => 'Mardin', '73' => 'Nigde', '74' => 'Siirt', '75' => 'Aksaray', '76' => 'Batman', '77' => 'Bayburt', '78' => 'Karaman', '79' => 'Kirikkale', '80' => 'Sirnak', '81' => 'Adana', '82' => 'Cankiri', '83' => 'Gaziantep', '84' => 'Kars', '85' => 'Zonguldak', '86' => 'Ardahan', '87' => 'Bartin', '88' => 'Igdir', '89' => 'Karabuk', '90' => 'Kilis', '91' => 'Osmaniye', '92' => 'Yalova', '93' => 'Duzce'], 'TT' => ['01' => 'Arima', '02' => 'Couva-Tabaquite-Talparo', '03' => 'Mayaro-Rio Claro', '05' => 'Port of Spain', '06' => 'Sangre Grande', '08' => 'Tunapuna-Piarco', '09' => 'Siparia', '10' => 'San Fernando', '11' => 'Tobago', '12' => 'Princes Town'], 'TW' => ['01' => 'Lienchiang', '02' => 'Kaohsiung', '03' => 'Taipei', '04' => 'Yunlin'], 'TZ' => ['02' => 'Pwani', '03' => 'Dodoma', '04' => 'Iringa', '05' => 'Kigoma', '06' => 'Kilimanjaro', '07' => 'Lindi', '08' => 'Mara', '09' => 'Mbeya', '10' => 'Morogoro', '11' => 'Mtwara', '12' => 'Mwanza', '13' => 'Kaskazini Pemba', '14' => 'Ruvuma', '15' => 'Shinyanga', '16' => 'Singida', '17' => 'Tabora', '18' => 'Tanga', '19' => 'Kagera', '20' => 'Kusini Pemba', '21' => 'Kusini Unguja', '22' => 'Kaskazini Unguja', '23' => 'Dar es Salaam', '24' => 'Rukwa', '25' => 'Mjini Magharibi', '26' => 'Arusha', '27' => 'Manyara'], 'UA' => ['01' => 'Cherkaska oblast', '02' => 'Chernihivska oblast', '03' => 'Chernivetska oblast', '04' => 'Dnipropetrovska oblast', '05' => 'Donetska oblast', '06' => 'Ivano-Frankivska oblast', '07' => 'Kharkivska oblast', '08' => 'Khersonska oblast', '09' => 'Khmelnytska oblast', '10' => 'Kirovohradska oblast', '11' => 'Avtonomna Respublika Krym', '12' => 'Kyiv', '13' => 'Kyivska oblast', '14' => 'Luhanska oblast', '15' => 'Lvivska oblast', '16' => 'Mykolaivska oblast', '17' => 'Odeska oblast', '18' => 'Poltavska oblast', '19' => 'Rivnenska oblast', '20' => 'Sevastopol', '21' => 'Sumska oblast', '22' => 'Ternopilska oblast', '23' => 'Vinnytska oblast', '24' => 'Volynska oblast', '25' => 'Zakarpatska oblast', '26' => 'Zaporizka oblast', '27' => 'Zhytomyrska oblast'], 'UG' => ['26' => 'Apac', '28' => 'Bundibugyo', '29' => 'Bushenyi', '30' => 'Gulu', '31' => 'Hoima', '33' => 'Jinja', '36' => 'Kalangala', '37' => 'Kampala', '38' => 'Kamuli', '39' => 'Kapchorwa', '40' => 'Kasese', '41' => 'Kibaale', '42' => 'Kiboga', '43' => 'Kisoro', '45' => 'Kotido', '46' => 'Kumi', '47' => 'Lira', '50' => 'Masindi', '52' => 'Mbarara', '56' => 'Mubende', '58' => 'Nebbi', '59' => 'Ntungamo', '60' => 'Pallisa', '61' => 'Rakai', '65' => 'Adjumani', '66' => 'Bugiri', '67' => 'Busia', '69' => 'Katakwi', '70' => 'Luwero', '71' => 'Masaka', '72' => 'Moyo', '73' => 'Nakasongola', '74' => 'Sembabule', '76' => 'Tororo', '77' => 'Arua', '78' => 'Iganga', '79' => 'Kabarole', '80' => 'Kaberamaido', '81' => 'Kamwenge', '82' => 'Kanungu', '83' => 'Kayunga', '84' => 'Kitgum', '85' => 'Kyenjojo', '86' => 'Mayuge', '87' => 'Mbale', '88' => 'Moroto', '89' => 'Mpigi', '90' => 'Mukono', '91' => 'Nakapiripirit', '92' => 'Pader', '93' => 'Rukungiri', '94' => 'Sironko', '95' => 'Soroti', '96' => 'Wakiso', '97' => 'Yumbe'], 'US' => ['AK' => 'Alaska', 'AL' => 'Alabama', 'AR' => 'Arkansas', 'AZ' => 'Arizona', 'CA' => 'California', 'CO' => 'Colorado', 'CT' => 'Connecticut', 'DC' => 'District of Columbia', 'DE' => 'Delaware', 'FL' => 'Florida', 'GA' => 'Georgia', 'HI' => 'Hawaii', 'IA' => 'Iowa', 'ID' => 'Idaho', 'IL' => 'Illinois', 'IN' => 'Indiana', 'KS' => 'Kansas', 'KY' => 'Kentucky', 'LA' => 'Louisiana', 'MA' => 'Massachusetts', 'MD' => 'Maryland', 'ME' => 'Maine', 'MI' => 'Michigan', 'MN' => 'Minnesota', 'MO' => 'Missouri', 'MS' => 'Mississippi', 'MT' => 'Montana', 'NC' => 'North Carolina', 'ND' => 'North Dakota', 'NE' => 'Nebraska', 'NH' => 'New Hampshire', 'NJ' => 'New Jersey', 'NM' => 'New Mexico', 'NV' => 'Nevada', 'NY' => 'New York', 'OH' => 'Ohio', 'OK' => 'Oklahoma', 'OR' => 'Oregon', 'PA' => 'Pennsylvania', 'RI' => 'Rhode Island', 'SC' => 'South Carolina', 'SD' => 'South Dakota', 'TN' => 'Tennessee', 'TX' => 'Texas', 'UT' => 'Utah', 'VA' => 'Virginia', 'VT' => 'Vermont', 'WA' => 'Washington', 'WI' => 'Wisconsin', 'WV' => 'West Virginia', 'WY' => 'Wyoming'], 'UY' => ['01' => 'Artigas', '02' => 'Canelones', '03' => 'Cerro Largo', '04' => 'Colonia', '05' => 'Durazno', '06' => 'Flores', '07' => 'Florida', '08' => 'Lavalleja', '09' => 'Maldonado', '10' => 'Montevideo', '11' => 'Paysandu', '12' => 'Rio Negro', '13' => 'Rivera', '14' => 'Rocha', '15' => 'Salto', '16' => 'San Jose', '17' => 'Soriano', '18' => 'Tacuarembo', '19' => 'Treinta y Tres'], 'UZ' => ['01' => 'Andijon', '02' => 'Buxoro', '03' => 'Farg\'ona', '04' => 'Jizzax', '05' => 'Xorazm', '06' => 'Namangan', '07' => 'Navoiy', '08' => 'Qashqadaryo', '09' => 'Qoraqalpog\'iston Respublikasi', '10' => 'Samarqand', '11' => 'Sirdaryo', '12' => 'Surxondaryo', '13' => 'Toshkent', '14' => 'Toshkent'], 'VC' => ['01' => 'Charlotte', '03' => 'Saint David', '04' => 'Saint George', '05' => 'Saint Patrick', '06' => 'Grenadines'], 'VE' => ['01' => 'Amazonas', '02' => 'Anzoategui', '03' => 'Apure', '04' => 'Aragua', '05' => 'Barinas', '06' => 'Bolivar', '07' => 'Carabobo', '08' => 'Cojedes', '09' => 'Delta Amacuro', '11' => 'Falcon', '12' => 'Guarico', '13' => 'Lara', '14' => 'Merida', '15' => 'Miranda', '16' => 'Monagas', '17' => 'Nueva Esparta', '18' => 'Portuguesa', '19' => 'Sucre', '20' => 'Tachira', '21' => 'Trujillo', '22' => 'Yaracuy', '23' => 'Zulia', '24' => 'Dependencias Federales', '25' => 'Distrito Capital', '26' => 'Vargas'], 'VN' => ['01' => 'An Giang', '03' => 'Ben Tre', '05' => 'Cao Bang', '09' => 'Dong Thap', '13' => 'Hai Phong', '20' => 'Ho Chi Minh', '21' => 'Kien Giang', '23' => 'Lam Dong', '24' => 'Long An', '30' => 'Quang Ninh', '32' => 'Son La', '33' => 'Tay Ninh', '34' => 'Thanh Hoa', '35' => 'Thai Binh', '37' => 'Tien Giang', '39' => 'Lang Son', '43' => 'Dong Nai', '44' => 'Ha Noi', '45' => 'Ba Ria - Vung Tau', '46' => 'Binh Dinh', '47' => 'Binh Thuan', '49' => 'Gia Lai', '50' => 'Ha Giang', '52' => 'Ha Tinh', '53' => 'Hoa Binh', '54' => 'Khanh Hoa', '55' => 'Kon Tum', '58' => 'Nghe An', '59' => 'Ninh Binh', '60' => 'Ninh Thuan', '61' => 'Phu Yen', '62' => 'Quang Binh', '63' => 'Quang Ngai', '64' => 'Quang Tri', '65' => 'Soc Trang', '66' => 'Thua Thien-Hue', '67' => 'Tra Vinh', '68' => 'Tuyen Quang', '69' => 'Vinh Long', '70' => 'Yen Bai', '71' => 'Bac Giang', '72' => 'Bac Kan', '73' => 'Bac Lieu', '74' => 'Bac Ninh', '75' => 'Binh Duong', '76' => 'Binh Phuoc', '77' => 'Ca Mau', '78' => 'Da Nang', '79' => 'Hai Duong', '80' => 'Ha Nam', '81' => 'Hung Yen', '82' => 'Nam Dinh', '83' => 'Phu Tho', '84' => 'Quang Nam', '85' => 'Thai Nguyen', '86' => 'Vinh Phuc', '87' => 'Can Tho', '88' => 'Dak Lak', '89' => 'Lai Chau', '90' => 'Lao Cai', '91' => 'Dak Nong', '92' => 'Dien Bien'], 'VU' => ['07' => 'Torba', '13' => 'Sanma', '15' => 'Tafea', '16' => 'Malampa', '17' => 'Penama', '18' => 'Shefa'], 'WS' => ['02' => 'Aiga-i-le-Tai', '03' => 'Atua', '04' => 'Fa\'asaleleaga', '06' => 'Va\'a-o-Fonoti', '07' => 'Gagaifomauga', '08' => 'Palauli', '09' => 'Satupa\'itea', '10' => 'Tuamasaga', '11' => 'Vaisigano'], 'YE' => ['01' => 'Abyan', '02' => '\'Adan', '03' => 'Al Mahrah', '04' => 'Hadramawt', '05' => 'Shabwah', '06' => 'Lahij', '07' => 'Al Bayda\'', '08' => 'Al Hudaydah', '09' => 'Al Jawf', '10' => 'Al Mahwit', '11' => 'Dhamar', '12' => 'Hajjah', '13' => 'Ibb', '14' => 'Ma\'rib', '15' => 'Sa\'dah', '16' => 'Raymah', '17' => 'Ta\'izz', '18' => 'Ad Dali\'', '19' => '\'Amran', '20' => 'Al Bayda\'', '21' => 'Al Jawf', '22' => 'Hajjah', '23' => 'Ibb', '24' => 'Lahij', '25' => 'Ta\'izz'], 'ZA' => ['01' => 'North-West', '02' => 'Kwazulu-Natal', '03' => 'Free State', '05' => 'Eastern Cape', '06' => 'Gauteng', '07' => 'Mpumalanga', '08' => 'Northern Cape', '09' => 'Limpopo', '10' => 'North-West', '11' => 'Western Cape'], 'ZM' => ['01' => 'Western', '02' => 'Central', '03' => 'Eastern', '04' => 'Luapula', '05' => 'Northern', '06' => 'North-Western', '07' => 'Southern', '08' => 'Copperbelt', '09' => 'Lusaka'], 'ZW' => ['01' => 'Manicaland', '02' => 'Midlands', '03' => 'Mashonaland Central', '04' => 'Mashonaland East', '05' => 'Mashonaland West', '06' => 'Matabeleland North', '07' => 'Matabeleland South', '08' => 'Masvingo', '09' => 'Bulawayo', '10' => 'Harare']];

		if (!isset($regions[$countryCode])) {
			return false;
		}

		foreach ($regions[$countryCode] as $regionCode => $region) {
			if (strtolower($region) == strtolower($regionName)) {
				return $regionCode;
			}
		}

		return false;
	}
}
